/* Poseidon game configuration */
/* Part of game design, no user editable data here. */

#include "minimal.h"
#include "eden.h"
#include "abel.h"
#include "cain.h"

// some basic defines
#define TEast 0
#define TWest 1
#define TGuerrila 2
#define TCivilian 3
#define TSideUnknown 4
#define TEnemy 5
#define TFriendly 6
#define TLogic 7

#define true 1
#define false 0

// type scope
// used for show entry

#define private 0 //! item is never visible
#define protected 1 //! "advanced designer" switch must be activated to use it
#define public 2 //! anyone can see/use it

#define ReadAndWrite 0 //! any modifications enabled
#define ReadAndCreate 1 //! only adding new class members is allowed
#define ReadOnly 2 //! no modifications enabled
#define ReadOnlyVerified 3 //! no modifications enabled, CRC test applied


#define Private		1
#define Corporal	2
#define Sergeant	3
#define Lieutnant	4
#define Captain		5
#define Major			6
#define Colonel		7
#define General		8

#define GTHeal		1
#define GTRepair	2
#define GTRefuel	3
#define GTReammo	4

//define Experiences

class CfgExperience
{
	access = ReadAndCreate;

	destroyUnit[]={unit1, unit2, unit3, unit4};
	// four price levels
	//		max price, basic experience
	unit1[] = {2000, 0};
	unit2[] = {200000, 200};
	unit3[] = {500000, 500};
	unit4[] = {1000000, 1000};

	destroyEnemy = 1;
	destroyFriendly = -7;
	destroyCivilian = -2;
	destroyYourUnit = -0.2; //for leadership only

	renegadeLimit = -2000;

	playerKilled = 0;

	commandCompleted = 0; //for subordinate soldier only
	commandFailed = 0; //for subordinate soldier only
 	followMe = 0; //for subordinate soldier only

	missionCompleted = 0; //for leadership only
	missionFailed = 0; //for leadership only
	
	ranks[] = 
	{
		0, //Private
		500, //Corporal
		1500, //Sergeant
		2500, //Lieutenant
		3500, //Captain
		5000, //Major
		7500  //Colonel
	};

	courage[] = 
	{
		0.20, //Private
		0.35, //Corporal
		0.55, //Sergeant
		0.65, //Lieutenant
		0.70, //Captain
		0.80, //Major
		0.90  //Colonel
	};
};

#include "cfgMaterials.hpp"

#include "cfgModels.hpp"
#include "cfgMoves.hpp"
#include "cfgWeapons.hpp"
#include "cfgVehicles.hpp"

// define surface properties

/*!
\patch 1.43 Date 1/22/2002 by Ondra
- Fixed: CfgSurfaces protected against addon modification.
*/

class CfgSurfaces
{
	// caution: wildcard pattern "files" is matched using special purpose matching
	// * may be used only as last character of the pattern
	// * matches any string in filename
	// ? matches any single character in filename
	// when six trailing question-marks are detected "??????", two patterns are matched:
	// full pattern and short pattern with ?????? omitted
	class Default
	{
		access = ReadOnly;
		files=default;
		rough=0.075;
		dust=0.1;
		soundEnviron = normalExt;
	};
	class Roadway
	{
		access = ReadOnly;
		files=silnice*;
		rough=0.005;
		dust=0.01;
		soundEnviron = road;
	};
	class Asfalt: Roadway
	{
		access = ReadOnly;
		files=asfalt*;
		rough=0.01;
		dust=0.05;
		soundEnviron = road;
	};
	class Cesta: Roadway
	{
		access = ReadOnly;
		files=cesta*;
		rough=0.08;
		dust=0.15;
		soundEnviron = gravel;
	};
	class Grass: Default
	{
		access = ReadOnly;
		files=tn??????;
		rough=0.11;
		dust=0.1;
		soundEnviron = normalExt;
	};
	class GrassAbel: Default
	{
		access = ReadOnly;
		files=tt??????;
		rough=0.11;
		dust=0.25;
		soundEnviron = grass;
	};
	class SandAbel: Default
	{
		access = ReadOnly;
		files=pi??????;
		rough=0.15;
		dust=0.6;
		soundEnviron = sand;
	};
	class RockAbel: Default
	{
		access = ReadOnly;
		files=sh??????;
		rough=0.2;
		dust=0.2;
		soundEnviron = rock;
	};

	class BetonAbel: Default
	{
		access = ReadOnly;
		files=bt??????;
		rough=0.05;
		dust=0.03;
		soundEnviron = rock;
	};
	class GrassHigh: Default
	{
		access = ReadOnly;
		files=tv??????;
		rough=0.12;
		dust=0.05;
		soundEnviron = grass;
	};
	class Forest
	{
		access = ReadOnly;
		files=pl??????;
		rough=0.12;
		dust=0.05;
		soundEnviron = forest;
	};
	class Sand: Default
	{
		access = ReadOnly;
		files=ps??????;
		rough=0.12;
		dust=0.5;
		soundEnviron = sand;
	};
	class Field: Default
	{
		access = ReadOnly;
		files=pol;
		rough=0.15;
		dust=0.3;
		soundEnviron = dirt;
	};
	class Village: Default
	{
		access = ReadOnly;
		files=bah;
		rough=0.08;
		dust=0.2;
		soundEnviron = normalExt;
	};
	class Runway: Roadway
	{ // runway is very clean
		access = ReadOnly;
		//files=lt??????;
		files=rw*;
		rough=0.001;
		dust=0.006;
		soundEnviron = road;
	};
	class Rock
	{
		access = ReadOnly;
		files=s???????;
		rough=0.15;
		dust=0.1;
		soundEnviron = rock;
	};
	class Water
	{
		access = ReadOnly;
		files=more_anim*;
		rough=0.0;
		dust=0.0;
		soundEnviron = water;
	};
	class Wood
	{
		access = ReadOnly;
		files=podlaha_prkna*;
		rough=0.15;
		dust=0.1;
		soundEnviron = wood;
	};	
	class Metal
	{
		access = ReadOnly;
		files=plechprolis*;
		rough=0.15;
		dust=0.1;
		soundEnviron = metal;
	};	
	class Beton
	{
		access = ReadOnly;
		files=kameny.pac;
		rough=0.15;
		dust=0.1;
		soundEnviron = rock;
	};	
	class Carpet
	{
		access = ReadOnly;
		files=dum_mesto_koberec*;
		rough=0.15;
		dust=0.1;
		soundEnviron = wood;
	};
	
	class SandBuilding: Default
	{
		access = ReadOnly;
		files=pisek01*;
		rough=0.12;
		dust=0.5;
		soundEnviron = sand;
	};
	class MudBuilding: Default
	{
		access = ReadOnly;
		files=hlinasterk*;
		rough=0.12;
		dust=0.5;
		soundEnviron = rock;
	};	
};

class CfgFonts
{
	class Korean
	{
/*
		TahomaB24 = GulimCheB48;
		TahomaB36 = GulimCheB48;
		TahomaB48 = GulimCheB64;
		CourierNewB64 = GulimCheB64;
		AudreysHandB48 = GulimCheB48;
		SteelfishB64 = GulimCheB64;
		Garamond64 = GulimCheB64;
		SteelfishB128 = GulimCheB128;
		AudreysHandI48 = GulimCheB48;
*/
/*
		TahomaB24 = hfont12;
		TahomaB36 = hfont16;
		TahomaB48 = hfont16;
		CourierNewB64 = hfont16;
		Garamond64 = hfont16;
		SteelfishB64 = hfont16;
		SteelfishB128 = hfont32;
		AudreysHandB48 = hfont12;
		AudreysHandI48 = hfont12;
*/
		TahomaB24 = hfont16;
		TahomaB36 = hfont16;
		TahomaB48 = hfont16;
		CourierNewB64 = hfont16;
		Garamond64 = hfont16;
		SteelfishB64 = hfont32;
		SteelfishB128 = hfont32_16;
		AudreysHandB48 = hfont16;
		AudreysHandI48 = hfont16;
	};
};

///////////////////////////////////////////////////////////////////////////////
// define UI

#define Black 0, 0, 0
// #define Green 0.2, 0.7, 0.2
#define Green 0.0, 0.6, 0.0
#define Red 0.7, 0.1, 0.0
// #define Yellow 0.7, 0.7, 0.2
#define Yellow 0.8, 0.6, 0.0
#define White 0.8, 0.8, 0.8
#define ShineGreen 0.07, 0.7, 0.2
#define ShineRed 1, 0.2, 0.2
#define ShineYellow 1, 1, 0
#define ShineWhite 1, 1, 1
#define Blue 0.1, 0.1, 0.9

#define Gray1			0.00, 0.00, 0.00
#define Gray2			0.20, 0.20, 0.20
#define Gray3			0.50, 0.50, 0.50
#define Gray4			0.60, 0.60, 0.60
#define Gray5			0.80, 0.80, 0.80

class CfgWrapperUI
{
	access = ReadAndCreate;
	class Colors
	{
		color1[] = {Gray1, 1.0};
		color2[] = {Gray2, 1.0};
		color3[] = {Gray3, 1.0};
		color4[] = {Gray4, 1.0};
		color5[] = {Gray5, 1.0};
	};
	class Background
	{
		alpha = 0.75;
		texture = "background.pac";
	};
	class TitleBar
	{
		alpha = 0.3;
		texture = "windowname.pac";
	};
	class GroupBox
	{
		alpha = 0.2;
	};
	class GroupBox2
	{
		alpha = 0.5;
		texture = "windowdisplay.pac";
	};
	class Button
	{
		color1[] = {Gray1, 0.3};
		color2[] = {Gray2, 0.3};
		color3[] = {Gray3, 0.3};
		color4[] = {Gray4, 0.3};
		color5[] = {Gray5, 0.3};
	};
	class Cursors
	{
		class Arrow
		{
			texture = kurzor_arrow;
			width = 16;
			height = 16;
			hotspotX = 0;
			hotspotY = 0;
			color[] = {White, 1};
		}
		class Track
		{
			texture = kurzor_track;
			width = 24;
			height = 24;
			hotspotX = 0.5;
			hotspotY = 0.5;
			color[] = {Red, 1};
		}
		class Move
		{
			texture = kurzor_move;
			width = 24;
			height = 24;
			hotspotX = 0.5;
			hotspotY = 0.5;
			color[] = {Green, 1};
		}
		class Scroll
		{
			texture = kurzor_scroll;
			width = 24;
			height = 24;
			hotspotX = 0.5;
			hotspotY = 0.5;
			color[] = {Yellow, 1};
		}
	};
	//soundOptions = "sound\animals\cock.wss";
};

class CfgInGameUI
{
	access = ReadAndCreate;

	imageCornerElement = cornern.paa;

	colorBackground[] = {Black, 0.8};
	colorBackgroundCommand[] = {Black, 0.3};
	colorBackgroundHelp[] = {Black, 0.2};
	colorText[] = {White, 1};
	class SideColors
	{
		colorFriendly[] = {Green, 1};
		colorEnemy[] = {Red, 1};
		colorNeutral[] = {White, 1};
		colorCivilian[] = {White, 1};
		colorUnknown[] = {Yellow, 1};
	};
	class IslandMap
	{
		colorFriendly[] = {0, 0.5, 0, 1};
		colorEnemy[] = {0.5, 0, 0, 1};
		colorNeutral[] = {0.5, 0.5, 0.5, 1};
		colorCivilian[] = {0, 0, 1, 1};
		colorUnknown[] = {0.5, 0.5, 0, 1};

		iconPlayer = you.paa;
		iconCheckpoint = target.paa;
		iconCamera = camera.paa;
		iconSelect = mkrouzek.paa;
		iconSensor = vlajka.paa;

		colorMe[] = {Red, 1};
		colorPlayable[] = {0.7, 0, 0.7, 1};
		colorSelect[] = {Green, 0.5};
		colorCamera[] = {Blue, 1};
		colorSensor[] = {Blue, 1};

		colorDragging[] = {White, 1};

		colorInactive[] = {1,1,1, 0.6};

		colorCountlines[] = {0, 0, 0, 0.33};
		colorCountlinesWater[] = {0, 0, 1, 1};
		colorExposureEnemy[] = {1.0, 0.2, 0.2, 0.5};
		colorExposureUnknown[] = {0.8, 0.8, 0.2, 0.5};
		colorRoads[] = {0.35, 0.2, 0.1, 0.8};
		colorGrid[] = {0.25, 0.25, 0.1, 0.75};
		colorGridMap[] = {0.25, 0.25, 0.1, 0.75};
		colorCheckpoints[] = {0.2, 0.2, 0.2, 1.0};
		colorMissions[] = {0.5, 0.5, 0.0, 0.5}; //remove
		colorActiveMission[] = {0.0, 0.0, 0.0, 1.0};

		colorPath[] = {0.0, 0.0, 1, 0.9};
		colorInfoMove[] = {1.0, 1.0, 1.0, 1.0};
		
		colorGroups[] = {0.0, 0.5, 0.5, 0.5}; //remove
		colorActiveGroup[] = {0.0, 1.0, 1.0, 1.0};
		
		colorSync[] = {0.0, 0.0, 1.0, 1.0};

		colorDetectorSync = {0,1,0,1} //todo

		colorLabelBackground[] = {0.0, 0.0, 0.0, 1.0};
	};
	class MPTable
	{
		color[] = {1, 1, 1, 1};
		colorBg[] = {0, 0, 0, 0.75};
		colorSelected[] = {1, 1, 1, 0.2};
		colorWest[] = {0, 1, 0, 1};
		colorEast[] = {1, 0, 0, 1};
		colorCiv[] = {0.8, 0.8, 0.8, 1};
		colorRes[] = {0.47, 0.47, 0.94, 1};
	};
	class TankDirection
	{
		left = 0.04;
		top =	0.007;
		width = 0.15;
		height = 0.195;

		color[] = {White, 1};
		colorHalfDammage[] = {Yellow, 1};
		colorFullDammage[] = {Red, 1};
		//imageHull = "tank_schema.paa";
		imageTower = "vez_schema.paa"; // TODO: remove

		//imageHull = "tank_schema.paa";
		imageTurret = "T_schema_vez.paa";
		imageGun = "T_schema_kanon.paa";
		imageObsTurret = "T_schema_velite2.paa";

		imageEngine = "T_schema_motor.paa";
		imageHull = "T_schema_trup.paa";

		imageLTrack = "T_schema_Lpas";
		imageRTrack = "T_schema_Ppas";

	};

	class Capture
	{
		colorBackground[] = {Black, 0.93};
		colorText[] = {Yellow, 1};
		colorLine[] = {White, 1};
	};
	class Picture
	{
		color[] = {White, 1};
		colorProblems[] = {Red, 1};
		imageBusy = busy.paa;
		imageWaiting = orders.paa;
		imageCommand = execute.paa;
	};
 	class Bar
	{
		imageBar = white.pac;
		colorBackground[] = {0.2, 0.5, 0.2, 0.5};
		colorGreen[] = {Green, 0.6};
		colorYellow[] = {Yellow, 0.6};
		colorRed[] = {Red, 0.8};
		colorBlinkOn[] = {ShineRed, 0.8};
		colorBlinkOff[] = {Red, 0.8};
		height = 0.01;
	};
	class Messages
	{
		color1[] = {Yellow, 1};
		color2[] = {Green, 1};
		color3[] = {White, 1};
	}
	class TacticalDisplay: SideColors
	{
		left = 0.24;
		top =	0.053;
		width = 0.52;
		height = 0.1;
		colorCamera[] = {0.1, 0.1, 0.1, 0.4};
		class Cursor
		{
			width = 0.015;
			height = 0.02;
			color[] = {White, 1};
		};
	};
	class ProgressFont
	{
		font = SteelfishB64;
	};
	class Compass
	{
		left = 0.24;
		top =	0.02;
		width = 0.52;
		height = 0.02;
		color[] = {White, 1};
		dirColor[] = {White, 1};
		turretDirColor[] = {Yellow, 1};
	};
	class Menu
	{
		left = 0.78;
		top =	0.02;
		width = 0.2;
		height = 0.28;
		colorChecked[] = {Yellow, 1};
		colorEnabled[] = {White, 1};
		colorDisabled[] = {0.4, 0.4, 0.4, 1};
		hideTime = 60;
	};
	class GameInfo
	{
		left = 0.78;
		top =	0.9;
		width = 0.2;
		height = 0.08;
	};
	class GroupDir
	{
		image = grouporient.paa;
/*
		left = 0.905;
		top = 0.64;
*/
		left = 0.05;
		top = 0.62;
		width = 0.075;
		height = 0.1;
		dimmStartTime = 10;
		dimmEndTime = 15;
	};

	class PlayerInfo
	{
		colorTime[] = {White, 1};
		left = 0.02;
		top =	0.02;
		width = 0.2;
		height = 0.28;
		class UnitPicture
		{
			width = 0.15;
			height = 0.16;
		};
		class Sign
		{
			height = 0.03;
			widthSector = 0.04;
			widthGroup = 0.02;
			widthUnit = 0.02;
		}
		class Side
		{
			height = 0.072;
			width = 0.06;
		};
		class HealthBar
		{
			width =	0.12;
		};
		class ArmorBar
		{
			width =	0.12;
		};
		class FuelBar
		{
			width =	0.12;
		};
		class ExperienceBar
		{
			width =	0.12;
			color[] = {White, 1};
		};
		dimmStartTime = 5;
		dimmEndTime = 10;
	};

	class Hint
	{
		dimmStartTime = 30;
		dimmEndTime = 35;
		sound[] = {ui\hint, db10, 1};
	};
	class Chat
	{
		sound[] = {ui\hint, db-10, 1};
	};

	class GroupInfo
	{
		left = 0.02;
		top =	0.90;
		width = 0.96;
		height = 0.08;
		colorIDNone[] = {Black, 1};
		colorIDNormal[] = {White, 1};
		colorIDSelected[] = {Green, 1};
		colorIDPlayer[] = {Yellow, 1};
		class Semaphore
		{
			imageSemaphore = white.pac;
			width = 0.0075;
			height = 0.01;
			colorHoldFire[] = {Red, 1};
		};
		imageDefaultWeapons = ivojak;
		imageNoWeapons = \misc\ibezezbrane.paa;

		dimm = 0.3; // alpha of non-active group info elements
	};
	class ConnectionLost
	{
		left = 0.0;
		top =	0.45;
		width = 1.0;
		height = 0.10;
		font = tahomaB36;
		size = 0.03;
		color[] = {1.0, 0.5, 0.25, 1.0};
	};
	class Cursor
	{
		// targeting cursor
		aim=W_weapon;
		// two colors - possible lock, locked
		weapon=W_lock;

		outArrow = UI_sipka.paa;

		select_target=target_active.paa;
		lock_target=target_locked.paa;
		
		//main battle cursors
		me=circle;
		meColor[] = {White, 0.8};
		dimmMe = 0.0;
		dimmMeStartTime = 5;
		dimmMeEndTime = 10;
		dimmCmdStartTime = 5;
		dimmCmdEndTime = 10;
		select=circle;
		selectColor[] = {Green, 0.8};
		leader=circle;
		leaderColor[] = {Green, 0.8};
		mission=M_mission;
		missionColor[] = {Yellow, 0.8};

		//tactical cursor
		tactical=T_tactical;
		move=T_basic;
		selected=T_select;
		attack=T_attack;
		getIn=T_getin;
		watch = kurzor_scroll;

		color[] = {White, 1};
		colorBackground[] = {Black, 0.6};
		colorLocked[] = {Red, 1};
		dimm = 0.15; // alpha of non-active cursor elements

		class Sign
		{
			height = 0.015;
			widthSector = 0.02;
			widthGroup = 0.01;
			widthUnit = 0.01;
		}
	
		// active targets
		activeWidth = 0.6;
		activeHeight = 0.8;
		activeMinimum = 0.05;
		activeMaximum = 0.1;
		enemyActiveColor[] = {Red, 0.7};
	};
};

class CfgDetectors
{
	objects[] = {EmptyDetector};
};

class CfgGlasses
{
	class None
	{
		name = $STR_CFG_GLASSES_NONE;
		texture = "";
	};
	class Spectacles
	{
		name = $STR_CFG_GLASSES_SPECTACLES;
		texture = "civilista_bryle";
	};
	class Sunglasses
	{
		name = $STR_CFG_GLASSES_SUNGLASSES;
		texture = "civilista_zrcadlovky";
	};
};

class CfgFaces
{
	//access = ReadAndCreate;
	// Default is needed
	class Default
	{
		name = $STR_CFG_FACES_DEFAULT;
		texture = xicht_2f.paa;
		east = false;
		west = false;
	};

	class Face1
	{
		name = "Peter P.";
		texture = xicht_a.paa;
		east = false;
		west = false;
	};
	class Face2
	{
		name = "Victor B.";
		texture = xicht_b.paa;
		east = false;
		west = true;
	};
	class Face3
	{
		name = "Bohous";
		texture = xicht_c.paa;
		east = false;
		west = false;
	};
	class Face4
	{
		name = "Mirek";
		texture = xicht_d.paa;
		east = false;
		west = true;
	};
	class Face5
	{
		name = "Peter S.";
		texture = xicht_e.paa;
		east = false;
		west = false;
	};
	class Face6
	{
		name = "Charles";
		texture = xicht_f.paa;
		east = false;
		west = false;
	};
	class Face7
	{
		name = "Peter V.";
		texture = xicht_g.paa;
		east = false;
		west = false;
	};
	class Face8
	{
		name = "Richard B.";
		texture = xicht_h.paa;
		east = false;
		west = true;
	};
	class Face9
	{
		name = "Charles M.";
		texture = xicht_i.paa;
		east = false;
		west = true;
	};
	class Face10
	{
		name = "Ian O'Hara";
		texture = xicht_j.paa;
		east = false;
		west = true;
	};
	class Face11
	{
		name = "Vojta N.";
		texture = xicht_k.paa;
		east = false;
		west = true;
	};
	class Face12
	{
		name = "Adam B.";
		texture = xicht_l.paa;
		east = false;
		west = true;
	};
	class Face13
	{
		name = "Peter B.";
		texture = xicht_m.paa;
		east = false;
		west = false;
	};
	class Face14
	{
		name = "Francesco F.";
		texture = xicht_n.paa;
		east = false;
		west = false;
	};
	class Face15
	{
		name = "Bill O.";
		texture = xicht_o.paa;
		east = false;
		west = false;
	};
	class Face16
	{
		name = "Colin F.";
		texture = xicht_p.paa;
		east = false;
		west = false;
	};
	class Face17
	{
		name = "Darren I.";
		texture = xicht_q.paa;
		east = false;
		west = false;
	};
	class Face18
	{
		name = "Eric J.";
		texture = xicht_r.paa;
		east = false;
		west = false;
	};
	class Face19
	{
		name = "Phill D.";
		texture = xicht_s.paa;
		east = false;
		west = true;
	};
	class Face20
	{
		name = "Graham U.";
		texture = xicht_t.paa;
		east = false;
		west = true;
	};
	class Face21
	{
		name = "Henry G.";
		texture = xicht_u.paa;
		east = false;
		west = false;
	};
	class Face22
	{
		name = "Ivan B.";
		texture = xicht_v.paa;
		east = false;
		west = false;
	};
	class Face23
	{
		name = "Ghulam K.";
		texture = xicht_w.paa;
		east = false;
		west = false;
	};
	class Face24
	{
		name = "Kevin B.";
		texture = xicht_x.paa;
		east = false;
		west = false;
	};
	class Face25
	{
		name = "Robert ";
		texture = xicht_y.paa;
		east = false;
		west = true;
	};
	class Face26
	{
		name = "Martin";
		texture = xicht_z.paa;
		east = false;
		west = true;
	};
	class Face27
	{
		name = "John A.";
		texture = xicht_2a.paa;
		east = false;
		west = false;
	};
	class Face28
	{
		name = "Bill G.";
		texture = xicht_2b.paa;
		east = false;
		west = true;
	};
	class Face29
	{
		name = "Peter O.";
		texture = xicht_2c.paa;
		east = false;
		west = true;
	};
	class Face30
	{
		name = "Henry H.";
		texture = xicht_2d.paa;
		east = false;
		west = true;
	};
	class Face31
	{
		name = "William G.";
		texture = xicht_2e.paa;
		east = false;
		west = true;
	};
	class Face32
	{
		name = "Arnold T.";
		texture = xicht_2f.paa;
		east = false;
		west = true;
	};
	class Face33
	{
		name = "Michael H.";
		texture = xicht_2g.paa;
		east = false;
		west = false;
	};
	class Face34
	{
		name = "John Fox";
		texture = xicht_2h.paa;
		east = false;
		west = true;
	};
	class Face35
	{
		name = "George McArthur";
		texture = xicht_2i.paa;
		east = false;
		west = true;
	};
	class Face36
	{
		name = "Peter Sun";
		texture = xicht_2j.paa;
		east = false;
		west = true;
	};
	class Face37
	{
		name = "Robert S.";
		texture = xicht_2k.paa;
		east = false;
		west = true;
	};
	class Face38
	{
		name = "John Way";
		texture = xicht_2l.paa;
		east = false;
		west = true;
	};
	class Face39
	{
		name = "Jack C.";
		texture = xicht_2m.paa;
		east = false;
		west = true;
	};
	class Face40
	{
		name = "J. C.";
		texture = xicht_2n.paa;
		east = false;
		west = false;
	};
	class Face41
	{
		name = "Mel D.";
		texture = xicht_2o.paa;
		east = false;
		west = true;
	};
	class Face42
	{
		name = "John Paul";
		texture = xicht_2p.paa;
		east = false;
		west = true;
	};
	class Face43
	{
		name = "Jirka M.";
		texture = xicht_2q.paa;
		east = false;
		west = true;
	};
	class Face44
	{
		name = "Honza K.";
		texture = xicht_2r.paa;
		east = true;
		west = true;
	};
	class Face45
	{
		name = "John A.";
		texture = xicht_2s.paa;
		east = true;
		west = true;
	};
	class Face46
	{
		name = "Ondrey N.";
		texture = xicht_2t.paa;
		east = true;
		west = true;
	};
	class Face47
	{
		name = "Ondrey S.";
		texture = xicht_2u.paa;
		east = true;
		west = true;
	};
	class Face48
	{
		name = "Gabriel K.";
		texture = xicht_2v.paa;
		east = true;
		west = true;
	};
	class Face49
	{
		name = "Oliver S.";
		texture = xicht_2w.paa;
		east = false;
		west = true;
	};
	class Face50
	{
		name = "Radan D.";
		texture = xicht_2x.paa;
		east = true;
		west = true;
	};
	class Face51
	{
		name = "George J.";
		texture = xicht_2y.paa;
		east = true;
		west = true;
	};
	class Face52
	{
		name = "Ota B.";
		texture = xicht_2z.paa;
		east= true;
		west = true;
	};

	/*
	class Face99
	{
		disabled=true;
		name = "Angelina";
		texture = xicht_a.paa;
		front = ang_face_f10.pac;
		side = ang_face_b9.pac;
		back = ang_face_z4.pac;
		east = false;
		west = false;
	};
	*/
	class Custom
	{
		name = $STR_CFG_FACES_CUSTOM;
		texture = white.pac;
		front = white.pac;
		side = white.pac;
		back = white.pac;
		east = false;
		west = false;
	};
};

class CfgFaceWounds
{
	access = ReadAndCreate;
	wounds[]=
	{
		\o\char\faceR01.paa,\o\char\faceR01_d.pac,
		\o\misc\eva.pac,\o\misc\eva_d.pac,
		\o\misc\kamila.pac,\o\misc\kamila_d.pac,
		\o\misc\lada.pac,\o\misc\lada_d.pac,
		\o\misc\lucie.pac,\o\misc\lucie_d.pac,
		\o\misc\marketa.pac,\o\misc\marketa_d.pac,
		\o\misc\nada.pac,\o\misc\nada_d.pac,

		#include "woundsFace.hpp"		

	};
};

class CfgMimics
{
	access = ReadAndCreate;
	class HeadPreview
	{
		microMimics=Micro;
	};
	class Micro
	{
		//          max offset (3d)       change time (min..max)
		lBrow[] =  {0.0020,0.0020,0.0010, 0.6,3.0};
		mBrow[] =  {0.0020,0.0020,0.0010, 0.6,2.5};
		rBrow[] =  {0.0020,0.0020,0.0010, 0.6,3.0};
		lMouth[] = {0.0010,0.0020,0.0010, 0.6,2.0};
		mMouth[] = {0.0000,0.0000,0.0000, 0.6,3.0};
		rMouth[] = {0.0010,0.0020,0.0010, 0.6,2.0};
	};
	class NoMicro
	{
		//          max offset (3d)       change time (min..max)
		lBrow[] =  {0.0000,0.0000,0.0000, 0.6,3.0};
		mBrow[] =  {0.0000,0.0000,0.0000, 0.6,2.5};
		rBrow[] =  {0.0000,0.0000,0.0000, 0.6,3.0};
		lMouth[] = {0.0000,0.0000,0.0000, 0.6,2.0};
		mMouth[] = {0.0000,0.0000,0.0000, 0.6,3.0};
		rMouth[] = {0.0000,0.0000,0.0000, 0.6,2.0};
	};
	class States
	{
		class Default
		{
			// {right, up} in cm
			lBrow[] = {0, 0};
			mBrow[] = {0, 0};
			rBrow[] = {0, 0};
			lMouth[] = {0, 0};
			mMouth[] = {0, 0};
			rMouth[] = {0, 0};
		};
		class Normal
		{
			// {right, up} in cm
			lBrow[] = {0, 0};
			mBrow[] = {0, 0};
			rBrow[] = {0, 0};
			lMouth[] = {0, 0};
			mMouth[] = {0, 0};
			rMouth[] = {0, 0};
		};
		class Smile
		{
			// {right, up} in cm
			lBrow[] = {0, 0.25};
			mBrow[] = {0, 0.25};
			rBrow[] = {0, 0.25};
			lMouth[] = {-0.5, 0.6};
			mMouth[] = {0, 0.0};
			rMouth[] = {0.5, 0.6};
		};
		class Hurt
		{
			// {right, up} in cm
			lBrow[] = {0, -0.35};
			mBrow[] = {0, -0.5};
			rBrow[] = {0, -0.6};
			lMouth[] = {0.5, -0.3};
			mMouth[] = {0, 0.3};
			rMouth[] = {-0.5, -0.6};
		};
		class Ironic
		{
			// {right, up} in cm
			lBrow[] = {0, -0.35};
			mBrow[] = {0, -0.35};
			rBrow[] = {0, -0.35};
			lMouth[] = {0.1, 0.3};
			mMouth[] = {0, 0.9};
			rMouth[] = {-0.1, 0.3};
		};
		class Sad
		{
			// {right, up} in cm
			lBrow[] = {0, +0.2};
			mBrow[] = {0, +0.2};
			rBrow[] = {0, +0.2};
			lMouth[] = {0.1, -0.5};
			mMouth[] = {0, -0.5};
			rMouth[] = {-0.1, -0.5};
		};
		class Cynic
		{
			// {right, up} in cm
			lBrow[] = {0, -0.35};
			mBrow[] = {0, 0.0};
			rBrow[] = {0, +0.05};
			lMouth[] = {0.2, -0.9};
			mMouth[] = {0, -0.2};
			rMouth[] = {0.0, 0};
		};
		class Surprised
		{
			// {right, up} in cm
			lBrow[] = {0, 0.5};
			mBrow[] = {0, 0.5};
			rBrow[] = {0, 0.5};
			lMouth[] = {0.0, -0.3};
			mMouth[] = {0, +0.3};
			rMouth[] = {0.0, -0.2};
		};

		class Agresive
		{
			// {right, up} in cm
			lBrow[] = {0, -0.25};
			mBrow[] = {0, -0.4};
			rBrow[] = {0, -0.3};
			lMouth[] = {+0.4, +0.5};
			mMouth[] = {0, +0.5};
			rMouth[] = {-0.4, -0.5};
		};
		class Angry
		{
			// {right, up} in cm
			lBrow[] = {+0.4, -0.5};
			mBrow[] = {+0.1, -0.4};
			rBrow[] = {-0.4, -0.5};
			lMouth[] = {+0.4, -0.9};
			mMouth[] = {0, -0.2};
			rMouth[] = {-0.4, -0.8};
		};
	
	};

	combat[]=
	{
		Sad,0.1,
		Surprised,0.1,
		Cynic,0.3,
		Angry,0.1,
		Normal
		
	
	};
	aware[]=
	{
		Angry, 0.2,
		Normal
		
	};
	safe[]=
	{
		Smile,0.1,
		Surprised,0.1,
		Normal
	};
	neutral[]=
	{
		Surprised,0.1,
		Sad,0.1,
		Normal
	};
	danger[]=
	{
		Surprised,0.4,
		Sad
	};
	dead[]={Hurt};
	hurt[]={Hurt};
};

// define sound FX

class CfgVoice
{
	access = ReadAndCreate;
	// different speakers
	voices[]={ Adam, Dan, George, Greg, John, Jonah, Marc, Patrick, Paul, Peter, Rich, Rob, Ted, Tom };
	voicePlayer = Adam;

	micOuts[]={micOut1, micOut2, micOut3};
	
	preview = "isayagain";

	class Words
	{

		//generic sounds
		micOut[] = {Mic_Out1};
		micOut1[]={static\over01};
		micOut2[]={static\over02};
		micOut3[]={static\over03};
		loop[]={static\loop};
		
		beepBeep[]={beep};
		pause[]={empty01sec};
		xmit[]={beep};

		//tank weapons
		switchTo[]={switchto};
		mgun[]={weapons\mgun};
		heat[]={weapons\sabot};
		shell[]={weapons\heat}; //change to SABOT
		weapon[]={weapons\weapon};


		// numbers - to add variants _one and one_
		all[]={numbers\all}; //missing sound
		allGroup[]={numbers\all}; //missin sound
		
		
		
		zero[]={numbers\zero};
		one[]={numbers\one};
		two[]={numbers\two};
		three[]={numbers\three};
		four[]={numbers\four};
		five[]={numbers\five};
		six[]={numbers\six};
		seven[]={numbers\seven};
		eight[]={numbers\eight};
		nine[]={numbers\nine};
		ten[]={numbers\ten};
		eleven[]={numbers\eleven};
		twelve[]={numbers\twelve};
		zerolong[]={numbers\zero};

		// phonetic alphabet
		alpha[]={alphabet\alpha};
		bravo[]={alphabet\bravo};
		charlie[]={alphabet\charlie};
		delta[]={alphabet\delta};
		echo[]={alphabet\echo};
		foxtrot[]={alphabet\foxtrot};
		golf[]={alphabet\golf};
		hotel[]={alphabet\hotel};
		india[]={alphabet\india};
		juliet[]={alphabet\juliet};
		kilo[]={alphabet\kilo};	
		lima[]={alphabet\lima};
		mike[]={alphabet\mike};	
		november[]={alphabet\november};	
		oscar[]={alphabet\oscar};
		papa[]={alphabet\papa};
		quebec[]={alphabet\quebec};
		romeo[]={alphabet\romeo};
		sierra[]={alphabet\sierra};
		tango[]={alphabet\tango};
		uniform[]={alphabet\uniform};
		victor[]={alphabet\victor};
		whiskey[]={alphabet\whiskey};
		xray[]={alphabet\xray};
		yankee[]={alphabet\yankee};
		zulu[]={alphabet\zulu};


		// teams
		whiteTeam[]={team\teamwhite};		// TODO: missing
		redTeam[]={team\teamred};			// TODO: missing
		greenTeam[]={team\teamgreen};		// TODO: missing
		blueTeam[]={team\teamblue};		// TODO: missing
		yellowTeam[]={team\teamyellow};	// TODO: missing


		//directon clock
		at10[] = {clockfacing\10oclock};
		at11[] = {clockfacing\11oclock};
		at12[] = {clockfacing\12oclock};
		at1[] = {clockfacing\1oclock};
		at2[] = {clockfacing\2oclock};
		at3[] = {clockfacing\3oclock};
		at4[] = {clockfacing\4oclock};
		at5[] = {clockfacing\5oclock};
		at6[] = {clockfacing\6oclock};
		at7[] = {clockfacing\7oclock};
		at8[] = {clockfacing\8oclock};
		at9[] = {clockfacing\9oclock};

		// TODO: record distances
		dist50[]={distance\50};
		dist100[]={distance\100};
		dist200[]={distance\200};
		dist500[]={distance\500};
		dist1000[]={distance\1000};
		dist2000[]={distance\2000};
		far[]={distance\far};

		// quarters
		north[]={north};				// TODO: missing
		northEast[]={northeast};		// TODO: missing
		east[]={east};				// TODO: missing
		southEast[]={southeast};		// TODO: missing
		south[]={south};				// TODO: missing
		southWest[]={southwest};		// TODO: missing
		west[]={west};				// TODO: missing
		northWest[]={northwest};		// TODO: missing

		//commands/messages

		//****units / objects
		ambulance[]={vehicles\ambulance};
		apc[]={vehicles\apc};
		boat[]={vehicles\boat};
		car[]={vehicles\car};
		crew[]={vehicles\crew};
		chopper[] = {vehicles\chopper};
		man[]={vehicles\man};
		machineGunner[]={vehicles\machinegunner};
		medic[]={vehicles\medic2};
		missileSoldier[]={vehicles\atsoldier};
		officer[]={vehicles\officer};
		pilot[]={pilot};
		plane[]={vehicles\plane};
		ship[]={vehicles\ship};
		soldier[]={vehicles\soldier};
		sniper[]={vehicles\sniper};
		tank[]={vehicles\tank};
		truck[]={vehicles\truck};
		tractor[]={vehicles\tractor};
		vehicle[]={vehicles\vehicle};
		specNas[]={vehicles\spetznatz};
		blackOp[]={vehicles\blackop};


		abrams[]={vehicles\abrams};
		blackhawk[]={vehicles\blackhawk};
		cobra[]={vehicles\cobra};
		jeep[]={vehicles\jeep};
		m113[]={vehicles\m113};
		m60[]={vehicles\m60};
		thunderbolt[]={vehicles\thunderbolt};


		BMP[]={vehicles\bmp};
		mi17[]={vehicles\mi17};
		hind[]={vehicles\hind};
		scudLauncher[]={vehicles\scudlauncher};
		T55[]={vehicles\T55};
		T72[]={vehicles\T72};
		T80[]={vehicles\T80};
		shilka[]={vehicles\shilka};
		UAZ[]={vehicles\UAZ};

		object[]={object};

		bunker[]={objects\bunker};
		building[]={objects\building};
		bush[]={objects\bush};
		chapel[]={objects\chapel};
		church[]={objects\church};
		cross[]={objects\cross};
		depot[]={objects\depot};
		forest[]={objects\forest};
		fuelStation[] = {objects\fuelstation};
		helipad[] ={objects\helipad};
		hospital[]={objects\hospital};
		house[]={objects\house};
		repairDepot[]={objects\repairdepot};
		rock[]={objects\rock};
		tree[]={objects\tree};

		enemy[]={people\enemy}; //has to be recorded
		friendly[]={people\friendly};
		civilian[]={people\civilian};
		resistance[]={people\resistance};
		unknown[]={people\unknown};


		// *****commands

		IsDown[]={isdown};
		Damned[]={damn}; //shall be damned???
		OhNo[]={ohno};
		
		Injured[]={injured};

		StatusRed[]={statusred};
		outOfFuel[]={outoffuel};
		outOfAmmo[]={outofammo};
		fuellow[]={fuellow};
		ammoLow[]={ammolow};
		position[]={position};

		thisIs[]={thisis};
		takingCommand[]={takingcommand};
		ISayAgain[]={isayagain};
		
		out[]={out}; //missing
		over[]={over}; //missing
		
		ready[]={ready};
		waiting[]={waiting};
		negative[]={negative};

		readyToFire[]={readytofire};
		cannotFire[]={cannotfire};

		canNotGetThere[]={cantgetthere};


		needMedic[]={medic};
		needAmmo[]={needammo};
		needFuel[]={needFuel};
		needRepairs[]={needRepairs};
		supporting[]={supporting};
		requestSupport[]={requestsupport};

		//to remove splitted formations
		form[]={form};

		column[]={column};
		StageredColumn[]={staggeredcolumn};
		Wedge[]={wedge};
		EchelonLeft[]={echelonleft};
		EchelonRight[]={echelonright};
		Vee[]={vee};
		Line[]={line};
		
		//new form commands
		formColumn[]={formcolumn};
		formStageredColumn[]={formstaggeredcolumn};
		formWedge[]={formwedge};
		formEchelonLeft[]={formechelonleft};
		formEchelonRight[]={formechelonright};
		formVee[]={formvee};
		formLine[]={formline};
		

		Careless[]={careless}; //Stand Down???
		AtEase[]={atease};
		StayAlert[]={stayalert};
		Danger[]={danger};
		FireAtWill[]={fireatwill};
		WeaponsFree[]={weaponsfree};
		GoGoGo[]={gogogo};
		HoldFire[]={holdfire};
		CeaseFire[]={ceasefire};
		DontFire[]={dontfire};

		engage[]={engage};
		engageAtWill[]={engageatwill};
		disengage[]={disengage};

		goProne[]={goprone};
		hitTheDirt[] = {hitthedirt};
		getDown[] = {getdown}; //to be added
		
		standUp[]={standup};
		keepLow[]={keeplow}; //keep low seems to be incorrect
		
		
		Advance[]={advance};
		StayBack[]={stayback};
		FlankLeft[]={flankleft};
		FlankRight[]={flankright};

		FireAt[]={fireat};
		Are[]={are}; //missing, team assignement ARE TEAM RED
		Is[]={is}; //is
		WaitForMe[]={waitforme};

		Watch[]={watch};
		scanHorizon[]={scanhorizon};

		NoTarget[]={notarget};
		KeepFormation[]={keepformation};

		TakeWeaponFrom[]={takeweaponfrom};
		TakeMagazineFrom[]={takemagazinefrom};
		ReportStatus[]={reportstatus};
		MoveTo[]={moveto};
		GoTo[]={goto};
		HealAt[]={healat};

		repairAt[]={repairat};
		refuelAt[]={refuelat};
		rearmAt[]={rearmat};

		returnToFormation[]={returntoformation};
		fallBackIntoFormation[]={fallbackintoformation};

		follow[]={follow};
		attack[]={attack};

		mount[]={getin}; //was mount
		getin[]={getin};
		boardIn[]={boardin}; //remove
		board[]={board}; //remove

		disembark[]={disembark};

		stop[]={halt}; //halt was stop
		halt[]={halt}; 
		hide[]={takecover}; //was hide
		takeCover[]={takecover}; //

		engaging[]={engaging}; 
		attacking[]={attacking}; //not in use 
		iAmOnHim[]={iamonhim};

		roger[]={roger};
		movingOn[]={movingon};
		onTheWay[]={ontheway};

		target[]={target};

		forward[]={forward};
		backward[]={reverse}; //now revers
		reverse[]={reverse};
		fast[]={fast};
		slow[]={slow};
		left[]={left};
		right[]={right};
		fire[]={fire};

		gunner[]={gunner};
		commander[]={tankcommander}; //has to be tankcommander !!!!! wrong sample name
		driver[]={driver};

		iVeGotHim[]={ivegothim};
		isHistory[]={ishistory};
		contact[]={contact};
		underFire[]={underfire};
		clear[]={clear};

		whereAreYou[]={whereareyou};
		repeat[]={repeat};
		stealth[]={stealth};
	};

	class Rob
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Rob\, Rob\};
		name="Rob";
	};

	class Adam
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Adam\, Rob\};
		name="Adam";
	};
	class Dan
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Dan\, Rob\};
		name="Dan";
	};

	class Greg
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Greg\, Rob\};
		name="Greg";
	};

	class George
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {George\, Rob\};
		name="George";
	};

	class John
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {John\, Rob\};
		name="John";
	};
	class Jonah
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Jonah\, Rob\};
		name="Jonah";
	};
	class Marc
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Marc\, Rob\};
		name="Marc";
	};	
	
	class Patrick
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Patrick\, Rob\};
		name="Patrick";
	};
	class Paul
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Paul\, Rob\};
		name="Paul";
	};	
	class Peter
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Peter\, Rob\};
		name="Peter";
	};	
	class Rich
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Rich\, Rob\};
		name="Rich";
	};
	class Ted
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Ted\, Rob\};
		name="Ted";
	};
	class Tom
	{
		variants[]={0.95, 1.0, 1.05};	// define variants - only one for player's voice
		// all speakers, single speaker
		directories[] = {Tom\, Rob\};
		name="Tom";
	};
};

class CfgHQIdentities
{
	access = ReadAndCreate;
	class Base
	{
		name = $STR_CFG_PAPABEAR;
		speaker="Dan";
		pitch=0.950000;
	};
	class HQ
	{
		name = $STR_CFG_PAPABEAR;
		speaker="Greg";
		pitch=1.050000;
	};
	class PAPA_BEAR
	{
		name = $STR_CFG_PAPABEAR;
		speaker="Greg";
		pitch=1.050000;
	};
	class AirBase
	{
		name = $STR_CFG_FIREFLYBASE;
		speaker="Greg";
		pitch=1.050000;
	};
};

class CfgSFX
{
	access = ReadAndCreate;
	// special
	// sfxfile, vol, frq, probab, min_delay, mid_delay, max_delay
	seagull[]={animals\gulls1,db-30,1, 1, 0.2, 1, 5};

	class Preview
	{
		// options volume controls
		effect[] = {"sound\weapons\m16burst.wss", db+0, 1.0};
		speech[] = {"voice\adam\isayagain.wss", db+0, 1.0};
		music[] = {"music\13.ogg", db+0, 1.0};
	};

	
	class Church
	{
		smallBell[]={Objects\bell1,db-20,1};
		largeBell[]={Objects\bell2,db-10,1};
	};

	

	
	/*
	sounds[] =
	{
		StreamSfx, AlarmSfx,
		Cricket1Sfx, Cricket2Sfx, Cricket3Sfx, CricketSfx,
		FrogSfx, FrogsSfx, OwlSfx, CowSfx,
		DogSfx, SorrowDogSfx, BadDogSfx, LittleDogSfx,
		BirdSingingSfx, CockSfx, ChickenSfx, FunMusicSfx,
		WolfSfx, CrowSfx, SeagullSfx,
		HedgeSparrow, Skylark, ForestLark, Nightingale,
		Jay, Owl, Crow2, Frog2,

		CA_AK, CA_M16, CA_Expl1
	};
	*/

	class CA_AK
	{
		sounds[]={sound1, sound2};
		name = $STR_CFG_SFX_CA_AK;
		
		sound1[]={"weapons\AK74single", db-20,1, 0.5, 0,2,5};
		sound2[]={"weapons\AK74burst", db-20,1, 0.4, 0,1,10};
		empty[]= {, , , , 1 , 5, 20};
	};
	class CA_M16
	{
		sounds[]={sound1, sound2};
		name = $STR_CFG_SFX_CA_M16;
		
		sound1[]={"weapons\M16single", db-20,1, 0.5, 0,2,5};
		sound2[]={"weapons\M16burst", db-20,1, 0.4, 0,1,10};
		empty[]= {, , , , 1 , 5, 20};
	};

	class CA_Expl1
	{
		sounds[]={sound1};
		name = $STR_CFG_SFX_CA_EXPL1;
		
		sound1[]={"weapons\explosion_large1", db-20,1, 0.5, 0,2,5};
		empty[]= {, , , , 1 , 5, 30};
	};




	class hedgesparrow	
	{
		sounds[]={sing1, sing2, sing3, sing4, sing5};
		name = $STR_CFG_SFX_HEDGESPARROW;
		
		sing1[]={"animals\hedspar1", db-50,1, 0.1, 0,0,0};
		sing2[]={"animals\hedspar2", db-50,1, 0.2, 0,0,0};
		sing3[]={"animals\hedspar3", db-50,1, 0.1, 0,0,0};
		sing4[]={"animals\hedspar4", db-50,1, 0.2, 0,0,0};
		sing5[]={"animals\hedspar5", db-50,1, 0.3, 0,0,0};
		empty[]= {, , , , 1 , 5, 80};
	};
	class skylark	
	{
		sounds[]={sing1, sing2, sing3, sing4, sing5, sing6, sing7};
		name = $STR_CFG_SFX_SKYLARK;
		
		sing1[]={"animals\skylark7", db-40,1, 0.1, 0.2,0.4,1};
		sing2[]={"animals\skylark6", db-40,1, 0.2, 0.2,0.3,1};
		sing3[]={"animals\skylark5", db-40,1, 0.1, 0.1,0.2,1.2};
		sing4[]={"animals\skylark4", db-40,1, 0.2, 0.1,0.2,1.2};
		sing5[]={"animals\skylark3", db-40,1, 0.1, 0.3,0.4,0.75};
		sing6[]={"animals\skylark2", db-40,1, 0.1, 0.2,0.4,0.8};
		sing7[]={"animals\skylark1", db-40,1, 0.1, 0.1,0.5,0.8};
		empty[]= {, , , , 1 , 5, 40};
	};
	class forestlark	
	{
		sounds[]={sing1, sing2, sing3, sing4, sing5, sing6};
		name = $STR_CFG_SFX_FORESTLARK;
		
		sing1[]={"animals\f_lark1", db-50,1, 0.1, 0.0,0.1,0.2};
		sing2[]={"animals\f_lark2", db-50,1, 0.1, 0.0,0.1,0.2};
		sing3[]={"animals\f_lark3", db-50,1, 0.1, 0.0,0.1,0.2};
		sing4[]={"animals\f_lark4", db-50,1, 0.1, 0.0,0.1,0.2};
		sing5[]={"animals\f_lark5", db-50,1, 0.2, 0.0,0.1,0.2};
		sing6[]={"animals\f_lark6", db-50,1, 0.2, 0.0,0.1,0.2};
		sing7[]={"animals\f_lark7", db-50,1, 0.2, 0.0,0.1,0.2};
		empty[]= {, , , , 1 , 5, 40};
	};
	class nightingale 	
	{
		sounds[]={sing1, sing2, sing3, sing4, sing5, sing6, sing7};
		name = $STR_CFG_SFX_NIGHTINGALE;
		
		sing1[]={"animals\n_gale1", db-50,1, 0.2, 0.1,0.2,0.3};
		sing2[]={"animals\n_gale2", db-50,1, 0.1, 0.1,0.2,0.3};
		sing3[]={"animals\n_gale3", db-50,1, 0.2, 0.1,0.2,0.3};
		sing4[]={"animals\n_gale4", db-50,1, 0.1, 0.1,0.2,0.3};
		sing5[]={"animals\n_gale5", db-50,1, 0.1, 0.1,0.2,0.3};
		sing6[]={"animals\n_gale6", db-50,1, 0.2, 0.1,0.2,0.3};
		sing7[]={"animals\n_gale7", db-50,1, 0.1, 0.1,0.2,0.3};
		empty[]= {, , , , 1 , 5, 40};
	};
	class jay	
	{
		sounds[]={sing1, sing2, sing3, sing4};
		name = $STR_CFG_SFX_JAY;
		
		sing1[]={"animals\jay1", db-40,1, 0.2, 0.2,0.4,1};
		sing2[]={"animals\jay2", db-40,1, 0.2, 0.2,0.3,1};
		sing3[]={"animals\jay3", db-40,1, 0.2, 0.1,0.2,1.2};
		sing4[]={"animals\jay4", db-40,1, 0.2, 0.1,0.2,1.2};
		empty[]= {, , , , 8 , 20, 40};
	};
	class owl	
	{
		sounds[]={sing1, sing2};
		name = $STR_CFG_SFX_OWL;
		
		sing1[]={"animals\owl2_1", db-50,1, 0.2, 0.0,0.5,1};
		sing2[]={"animals\owl2_2", db-50,1, 0.2, 0.0,0.5,1};
		empty[]= {, , , , 1 , 5, 40};
	};
	class crow2
	{
		sounds[]={sing1, sing2, sing3, sing4, sing5, sing6};
		name = $STR_CFG_SFX_CROW2;
		
		sing1[]={"animals\crow2_1", db-40,1, 0.1, 0.2,0.4,1};
		sing2[]={"animals\crow2_2", db-40,1, 0.1, 0.2,0.3,1};
		sing3[]={"animals\crow2_3", db-40,1, 0.1, 0.1,0.2,1.2};
		sing4[]={"animals\crow2_4", db-40,1, 0.1, 0.1,0.2,1.2};
		sing5[]={"animals\crow2_5", db-40,1, 0.1, 0.1,0.2,1.2};
		sing6[]={"animals\crow2_6", db-40,1, 0.1, 0.1,0.2,1.2};
		empty[]= {, , , , 1 , 5, 50};
	};
	class frog2
	{
		sounds[]={sing1, sing2, sing3};
		name = $STR_CFG_SFX_FROG2;
		
		sing1[]={"animals\frog2_1", db-40,1, 0.3, 0.0,0.1,0.2};
		sing2[]={"animals\frog2_2", db-40,1, 0.3, 0.0,0.1,0.2};
		sing3[]={"animals\frog2_3", db-40,1, 0.3, 0.0,0.1,0.2};
		empty[]= {, , , , 1 , 5, 40};
	};
	class SeagullSfx
	{
		sounds[]={seagull1, Seagull2, Seagull3, Seagull4, Seagull5};
		name = $STR_CFG_SFX_SEAGULL;
		
		seagull1[]={animals\gulls1, db-30,1, 0.15, 0.1,0.5,5};
		seagull2[]={animals\gulls2, db-30,1, 0.2, 0.1,0.5,5};
		seagull3[]={animals\gulls3, db-30,1, 0.15, 0.1,0.5,5};
		seagull4[]={animals\gulls4, db-30,1, 0.24, 0.1,0.5,5};
		seagull5[]={animals\gulls5, db-30,1, 0.2, 0.1,0.5,5};
		empty[]={ , , , , 0.2,2,20};
	};
	class StreamSfx
	{
		sounds[]={Stream01};
		name = $STR_DN_STREAM;
		
		Stream01[]={objects\stream, db-100,1, 1, 1,1,1};
		empty[]={ , , , , 0.0,0.0,0.0};
	};
	class AlarmSfx
	{
		sounds[]={Alarm};
		name = $STR_DN_ALARM;
		
		Alarm[]={objects\sirena, db-0,1, 1, 0.0,0.0,0.0};
		empty[]={ , , , , 0.0,0.0,0.0};
	};

	class Cricket1Sfx
	{
		sounds[]={Cricket01};
		name = $STR_DN_CRICKET1;
		
		Cricket01[]={animals\cricket01, db-60,1, 0.96, 0.0,0.0,0.0};
		empty[]={ , , , , 0.0,2,60};
	};
	class Cricket2Sfx
	{
		sounds[]={Cricket01};
		name = $STR_DN_CRICKET2;
		
		Cricket01[]={animals\cricket02, db-50,1, 0.97, 0.0,0.0,0.0};
		empty[]={ , , , , 0.0,3,60};
	};
	class Cricket3Sfx
	{
		sounds[]={Cricket01};
		name = $STR_DN_CRICKET3;
		
		Cricket01[]={animals\crickets06, db-60,1, 0.98, 0.0,0.0,0.0};
		empty[]={ , , , , 0.0,6,60};
	};

	class CricketSfx
	{
		sounds[]={Cricket04};
		name = $STR_DN_CRICKET4;
		
		Cricket04[]={animals\crickets04, db-60,1, 1, 0.0,0.0,0.0};
		empty[]={ , , , , 0.0,2,8};
	};

	class FrogSfx
	{
		sounds[]={Frog01, Frog02};
		name = $STR_DN_FROG;
		
		Frog01[]={animals\frog1_1, db-60.2,1, 0.8, 0.0,0.0,0.0};
		Frog02[]={animals\frog1_2, db-60,1, 0.1, 0.0,0.0,0.0};
		empty[]={ , , , , 0.1,0.5,12};
	};

	class FrogsSfx
	{
		sounds[]={Frog01};
		name = $STR_DN_FROGS;
		
		Frog01[]={animals\frogs, db-60,1, 1, 0.0,0.0,0.0};
		empty[]={ , , , , 0,0,0};
	};

	class OwlSfx
	{
		sounds[]={Owl1, Owl2};
		name = $STR_DN_OWL;
		
		Owl1[]={animals\owl1_1, db-60,1, 0.6, 0.1, 0.5, 5};
		Owl2[]={animals\owl1_2, db-60,1, 0.2, 0.1, 0.5, 5};
		empty[]={ , , , , 0.5, 2, 12};
	};
	class CowSfx
	{
		sounds[]={moo1, moo2};
		name = $STR_DN_COW;
		
		moo1[]={animals\cow_moo01, db-60,1, 0.4, 0.1,0.5,5};
		moo2[]={animals\cow_moo02, db-60,1, 0.4, 0.1,0.5,5};
		empty[]={ , , , , 0.1,0.5,2};
	};
	class WolfSfx
	{
		sounds[]={wolf1, wolf2, wolf3};
		name = $STR_DN_WOLF;
		
		wolf1[]={animals\wolf1, db-60,1, 0.3, 0.1,0.5,5};
		wolf2[]={animals\wolf2, db-60,1, 0.3, 0.1,0.5,5};
		wolf3[]={animals\wolf3, db-60,1, 0.3, 0.1,0.5,5};
		empty[]={ , , , , 0.5,4,50};
	};
	class CrowSfx
	{
		sounds[]={crow1, crow2, crow3};
		name = $STR_DN_CROW;
		
		crow1[]={animals\crow1_1, db-60,1, 0.2, 0.1,0.5,5};
		crow2[]={animals\crow1_2, db-60,1, 0.2, 0.1,0.5,5};
		crow3[]={animals\crow1_3, db-60,1, 0.2, 0.1,0.5,5};
		empty[]={ , , , , 2,10,30};
	};
	class DogSfx
	{
		sounds[]={dog1, dog2, dog3};
		name = $STR_DN_DOG;
		
		dog1[]={animals\dog_bark03, db-40,1, 0.3, 0.1,0.5,5};
		dog2[]={animals\dog_bark04, db-40,1, 0.3, 0.1,0.5,5};
		dog3[]={animals\dog_bark05, db-45,1, 0.3, 0.1,0.5,5};
		empty[]={ , , , , 3,15,90};
	};

	class SorrowDogSfx
	{
		sounds[]={sorrowdog1, sorrowdog2, sorrowdog3, sorrowdog4};
		name = $STR_DN_SORROW_DOG;
		
		sorrowdog1[]={animals\dog_bark04, db-40,1, 0.2, 0.1,0.5,5};
		sorrowdog2[]={animals\dog_bark05, db-40,1, 0.2, 0.1,0.5,5};
		sorrowdog3[]={animals\dog_yelp02, db-45,1, 0.2, 0.1,0.5,5};
		sorrowdog4[]={animals\dog_yelp03, db-50,1, 0.2, 0.1,0.5,5};
		empty[]= {, , , , 0.2,3,8};
	};
	class BadDogSfx
	{
		sounds[]={baddog1, baddog2, baddog3};
		name = $STR_DN_BAD_DOG;
		
		baddog1[]={animals\dog_bark04, db-37,1, 0.3, 0.1,0.5,5};
		baddog2[]={animals\dog_bark05, db-37,1, 0.3, 0.1,0.5,5};
		baddog3[]={animals\dog_maul01, db-35,1, 0.3, 0.1,0.5,5};
		empty[]={, , , , 0.1,2,5};
	};

	class LittleDogSfx
	{
		sounds[]={littledog1};
		name = $STR_DN_LITTLE_DOG;
		
		littledog1[]={animals\dog_bark04, db-55,1, 0.8, 0.1,0.5,5};
		empty[]={, , , , 0.2,5,3,8};
	};

	class BirdSingingSfx
	{
		sounds[]={sing1, sing1a, sing2, sing2a, sing3, sing4, sing5, sing6, sing7, sing8, sing9};
		name = $STR_DN_BIRDSING;
		
		sing1[]={animals\birdsing01, db-50,1, 0.1, 0.2,0.4,1};
		sing1a[]={animals\birdsing01, db-55,1, 0.08, 0.2,0.3,1};
		sing2[]={animals\birdsing02, db-60,1, 0.1, 0.1,0.2,1.2};
		sing2a[]={animals\birdsing02, db-45,1, 0.08, 0.1,0.2,1.2};
		sing3[]={animals\birdsing03, db-50,1, 0.08, 0.3,0.4,0.75};
		sing4[]={animals\birdsing04, db-50,1, 0.08, 0.2,0.4,0.8};
		sing5[]={animals\birdsing05, db-50,1, 0.08, 0.1,0.5,0.8};
		sing6[]={animals\birdsing06, db-50,1, 0.08, 0.1,0.3,0.8};
		sing7[]={animals\birdsing07, db-50,1, 0.08, 0.1,0.6,0.8};
		sing8[]={animals\birdsing08, db-55,1, 0.08, 0.1,0.6,0.8};
		sing9[]={animals\birdsing09, db-55,1, 0.08, 0.1,0.6,0.8};
		empty[]= {, , , , 1 , 5, 80};
	};

	class CockSfx
	{
		sounds[]={cock};
		name = $STR_DN_COCK;
		
		cock[]={animals\cock, db-40, 1, 0.5, 0.1,0.5,5};
		empty[]={, , , , , 1, 30, 90};
	};
	class ChickenSfx
	{
		sounds[]={chicken1, chicken2};
		name = $STR_DN_CHICKEN;
		
		chicken1[]={animals\chicken01, db-50,1, 0.3, 0.1,0.5,5};
		chicken2[]={animals\chicken02, db-50,1, 0.3, 0.1,0.5,5};
		empty[]={, , , , , 1, 20, 60};
	};
	class FunMusicSfx
	{
		sounds[]={music1};
		name = 'Music';
		
		music1[]={Objects\Fun_music, db-50,1, 1, 0,0,0};
		empty[]={, , , , , 0, 0, 0};
	};
};

// define environmental sounds

class CfgEnvSounds
{
	access = ReadAndCreate;
	// list of environmental sounds for editor
	/*
	sounds[] =
	{
		Default, Rain, Sea, Meadows, Trees, Hills, Combat
	};
	*/
	class Default // editor - sounds from landscape
	{
		name = $STR_CFG_ENVSOUNDS_DEFAULT;
		sound[]={"$DEFAULT$",0,1};
		soundNight[]={"$DEFAULT$",0,1};
	};
	class Rain // rain
	{
		name = $STR_DN_RAIN;
		sound[]={Environmental\Rain_hard,db-55,1};
		soundNight[]={Environmental\Rain_hard,db-55,1};
	};
	class Sea // sea
	{
		name = $STR_DN_SEA;
		sound[]={environmental\wave_break,db-70,1};
		soundNight[]={environmental\wave_break,db-70,1};
	};
	class Meadows // default - no trees, no sea, no hills ...
	{
		name = $STR_DN_MEADOWS;
		sound[]={animals\crickets07,db-85,1};
		soundNight[]={animals\crickets03,db-85,1};
	};
	class Trees // trees
	{
		name = $STR_DN_TREES;
		sound[]={environmental\treesbirds,db-75,1};
		soundNight[]={animals\crickets03,db-75,1};
	};
	class Hills // hills > 250m
	{
		name = $STR_DN_HILLS;
		sound[]={environmental\wind_heavy,db-75,1};
		soundNight[]={environmental\wind_whistle,db-75,1};
	};
	class Combat // desinger effect
	{
		name = $STR_CFG_ENVSOUNDS_COMBAT;
		sound[]={environmental\battle1,db-40,1};
		soundNight[]={environmental\battle2,db-40,1};
	};
};
// define destroy effects
class CfgDestroy
{
	access = ReadAndCreate;
	class EngineHit
	{
		sound[]={Explosions\fuel_explosion,db20,1};
	};
	class BuildingHit
	{
		sound[]={Explosions\BuildingHit,db20,1};
	};
	class TreeHit
	{
		sound[]={Explosions\Treehit1,db-30,1};
	};
};

class CfgHeads
{
	access = ReadAndCreate;
	class Air
	{
		friction=10;
		movement=160;
		maxAmp=0.05;
		maxSpeed=3;
		radius=0.2;
	};
	class Land
	{
		friction=20;
		movement=260;
		maxAmp=0.1;
		maxSpeed=4;
		radius=0.3;
	};
};
// define other effects
class CfgEffects
{
	access = ReadAndCreate;
	class ThunderboltNorm
	{
		model=blesk1.p3d;
		soundNear[]={Environmental\thundershort,db+50,1};
		soundFar[]={Environmental\thunderlong,db+50,1};
	};
	class ThunderboltHeavy
	{
		model=blesk2.p3d;
		soundNear[]={Environmental\thunderhard,db+50,1};
		soundFar[]={Environmental\thunder,db+50,1};
	};
	class Rain
	{
		texture=desta.01.paa;
	};
};

// define house windows
class CfgWindows
{
	access = ReadAndCreate;
	textureWindow=oknozhas.pac;
	textureWindowShine=oknosvit.pac;
	textureWindowBroken=strepyzhas.pac;
	textuerWindowMan=chlapvokne.pac;
	soundWindowBroken[]={43glass,1,1};
	soundDoor[]={door,0.7,1};
};


class CfgMusic
{
	access = ReadAndCreate;

	class 7thDecide
	{
		name = $STR_CFG_MUSIC_7TH_DECIDE;
		sound[] = {\Music\Seventh_decide.ogg, db+0, 1.0};
	};
	class 7thIAmGonaFly
	{
		name = $STR_CFG_MUSIC_7TH_IAMGONAFLY;
		sound[] = {\Music\Seventh_iamgonnafly.ogg, db+0, 1.0};
	};

	class 7thLifeless
	{
		name = $STR_CFG_MUSIC_7TH_LIFELESS;
		sound[] = {\Music\Seventh_lifeless.ogg, db+0, 1.0};
	};

	class 7thOverdose
	{
		name = $STR_CFG_MUSIC_7TH_OVERDOSE;
		sound[] = {\Music\Seventh_overdose.ogg, db+0, 1.0};
	};

	class Track1
	{
		name = $STR_CFG_MUSIC_TRACK1;
		sound[] = {\Music\01.ogg, db+0, 1.0};
	};
	class Track2
	{
		name = $STR_CFG_MUSIC_TRACK2;
		sound[] = {\Music\02.ogg, db+0, 1.0};
	};
	class Track3
	{
		name = $STR_CFG_MUSIC_TRACK3;
		sound[] = {\Music\03.ogg, db+0, 1.0};
	};
	class Track4
	{
		name = $STR_CFG_MUSIC_TRACK4;
		sound[] = {\Music\04.ogg, db+0, 1.0};
	};
	class Track5
	{
		name = $STR_CFG_MUSIC_TRACK5;
		sound[] = {\Music\05.ogg, db+0, 1.0};
	};
	class Track6
	{
		name = $STR_CFG_MUSIC_TRACK6;
		sound[] = {\Music\06.ogg, db+0, 1.0};
	};
	class Track7
	{
		name = $STR_CFG_MUSIC_TRACK7;
		sound[] = {\Music\07.ogg, db+0, 1.0};
	};
	class Track8
	{
		name = $STR_CFG_MUSIC_TRACK8;
		sound[] = {\Music\08.ogg, db+0, 1.0};
	};
	class Track9
	{
		name = $STR_CFG_MUSIC_TRACK9;
		sound[] = {\Music\09.ogg, db+0, 1.0};
	};
	class Track10
	{
		name = $STR_CFG_MUSIC_TRACK10;
		sound[] = {\Music\10.ogg, db+0, 1.0};
	};
	class Track11
	{
		name = $STR_CFG_MUSIC_TRACK11;
		sound[] = {\Music\11.ogg, db+0, 1.0};
	};
	class Track12
	{
		name = $STR_CFG_MUSIC_TRACK12;
		sound[] = {\Music\12.ogg, db+0, 1.0};
	};
	class Track13
	{
		name = $STR_CFG_MUSIC_TRACK13;
		sound[] = {\Music\13.ogg, db+0, 1.0};
	};
	class Track14
	{
		name = $STR_CFG_MUSIC_TRACK14;
		sound[] = {\Music\14.ogg, db+0, 1.0};
	};
	class Track15
	{
		name = $STR_CFG_MUSIC_TRACK15;
		sound[] = {\Music\15.ogg, db+0, 1.0};
	};
	class Track16
	{
		name = $STR_CFG_MUSIC_TRACK16;
		sound[] = {\Music\16.ogg, db+0, 1.0};
	};
	class Frost
	{
		name = $STR_CFG_MUSIC_FROST;
		sound[] = {\Music\frost.ogg, db+0, 1.0};
	};
};



class CfgSounds
{
	access = ReadAndCreate;
	/*
	sounds[] =
	{
		Eng1, Eng2, Eng3, Eng4, Eng5,
		Eng6, Eng7, Eng8, Eng9, Eng10,
		Eng11, Eng12, Eng13, Eng14, Eng15,
		Eng16, Eng17, Eng18, Eng19, Eng20,
		Eng21, Eng22, Eng23, Eng24, Eng25,
		Eng26, Eng27, Eng28, Eng29, Eng30,		
		Eng31, Eng32, Eng33, Eng34, Eng35,
		Eng36, Eng37, Eng38, Eng39, Eng40,		
		Eng41,
		
		Rus1, Rus2, Rus3, Rus4, Rus5,
		Rus6, Rus7, Rus8, Rus9, Rus10,
		Rus11, Rus12, Rus13, Rus14, Rus15,
		Rus16, Rus17, Rus18, Rus19, Rus20,
		
		Alarm
	};
	*/
	// name, sound


	class Rus1
	{
		name = $STR_CFG_SOUNDS_RUS1;
		sound[] = {"voices\rus_amerikanskije", db-20, 1.0};
		titles[]={ };
	};
	class Rus2
	{
		name = $STR_CFG_SOUNDS_RUS2;
		sound[] = {"voices\rus_begite", db-20, 1.0};
		titles[]={ };
	};
	class Rus3
	{
		name = $STR_CFG_SOUNDS_RUS3;
		sound[] = {"voices\rus_cjerta", db-20, 1.0};
		titles[]={ };
	};
	class Rus4
	{
		name = $STR_CFG_SOUNDS_RUS4;
		sound[] = {"voices\rus_cjort", db-20, 1.0};
		titles[]={ };
	};
	class Rus5
	{
		name = $STR_CFG_SOUNDS_RUS5;
		sound[] = {"voices\rus_cjort", db-20, 1.0};
		titles[]={ };
	};
	class Rus6
	{
		name = $STR_CFG_SOUNDS_RUS6;
		sound[] = {"voices\rus_hejty", db-20, 1.0};
		titles[]={ };
	};
	class Rus7
	{
		name = $STR_CFG_SOUNDS_RUS7;
		sound[] = {"voices\rus_jazdajus", db-20, 1.0};
		titles[]={ };
	};
	class Rus8
	{
		name = $STR_CFG_SOUNDS_RUS8;
		sound[] = {"voices\rus_mamocka", db-20, 1.0};
		titles[]={ };
	};
	class Rus9
	{
		name = $STR_CFG_SOUNDS_RUS9;
		sound[] = {"voices\rus_nestrelajte", db-20, 1.0};
		titles[]={ };
	};
	class Rus10
	{
		name = $STR_CFG_SOUNDS_RUS10;
		sound[] = {"voices\rus_ogon", db-20, 1.0};
		titles[]={ };
	};
	class Rus11
	{
		name = $STR_CFG_SOUNDS_RUS11;
		sound[] = {"voices\rus_ostonovitogon", db-20, 1.0};
		titles[]={ };
	};
	class Rus12
	{
		name = $STR_CFG_SOUNDS_RUS12;
		sound[] = {"voices\rus_otchodi", db-20, 1.0};
		titles[]={ };
	};
	class Rus13
	{
		name = $STR_CFG_SOUNDS_RUS13;
		sound[] = {"voices\rus_pamagite", db-20, 1.0};
		titles[]={ };
	};
	class Rus14
	{
		name = $STR_CFG_SOUNDS_RUS14;
		sound[] = {"voices\rus_stoj", db-20, 1.0};
		titles[]={ };
	};
	class Rus15
	{
		name = $STR_CFG_SOUNDS_RUS15;
		sound[] = {"voices\rus_trevoga", db-20, 1.0};
		titles[]={ };
	};
	class Rus16
	{
		name = $STR_CFG_SOUNDS_RUS16;
		sound[] = {"voices\rus_vodka1", db-20, 1.0};
		titles[]={ };
	};
	class Rus17
	{
		name = $STR_CFG_SOUNDS_RUS17;
		sound[] = {"voices\rus_vodka2", db-20, 1.0};
		titles[]={ };
	};
	class Rus18
	{
		name = $STR_CFG_SOUNDS_RUS18;
		sound[] = {"voices\rus_vperjod", db-20, 1.0};
		titles[]={ };
	};
	class Rus19
	{
		name = $STR_CFG_SOUNDS_RUS19;
		sound[] = {"voices\rus_zdescisto", db-20, 1.0};
		titles[]={ };
	};
	class Rus20
	{
		name = $STR_CFG_SOUNDS_RUS20;
		sound[] = {"voices\rus_zdochni", db-20, 1.0};
		titles[]={ };
	};
	class Eng1
	{
		name = $STR_CFG_SOUNDS_ENG1;
		sound[] = {"voices\eng_bastards1", db-20, 1.0};
		titles[]={ };
	};
	class Eng2
	{
		name = $STR_CFG_SOUNDS_ENG2;
		sound[] = {"voices\eng_bastards2", db-20, 1.0};
		titles[]={ };
	};	
	class Eng3
	{
		name = $STR_CFG_SOUNDS_ENG3;
		sound[] = {"voices\eng_bastards3", db-20, 1.0};
		titles[]={ };
	};	

	class Eng4
	{
		name = $STR_CFG_SOUNDS_ENG4;
		sound[] = {"voices\eng_commie1", db-20, 1.0};
		titles[]={ };
	};
	class Eng5
	{
		name = $STR_CFG_SOUNDS_ENG5;
		sound[] = {"voices\eng_commie2", db-20, 1.0};
		titles[]={ };
	};
	class Eng6
	{
		name = $STR_CFG_SOUNDS_ENG6;
		sound[] = {"voices\eng_coverme1", db-20, 1.0};
		titles[]={ };
	};
	class Eng7
	{
		name = $STR_CFG_SOUNDS_ENG7;
		sound[] = {"voices\eng_coverme2", db-20, 1.0};
		titles[]={ };
	};
	class Eng8
	{
		name = $STR_CFG_SOUNDS_ENG8;
		sound[] = {"voices\eng_die1", db-20, 1.0};
		titles[]={ };
	};
	class Eng9
	{
		name = $STR_CFG_SOUNDS_ENG9;
		sound[] = {"voices\eng_die2", db-20, 1.0};
		titles[]={ };
	};
	class Eng10
	{
		name = $STR_CFG_SOUNDS_ENG10;
		sound[] = {"voices\eng_die3", db-20, 1.0};
		titles[]={ };
	};
	class Eng11
	{
		name = $STR_CFG_SOUNDS_ENG11;
		sound[] = {"voices\eng_dontshoot", db-20, 1.0};
		titles[]={ };
	};	
	class Eng12
	{
		name = $STR_CFG_SOUNDS_ENG12;
		sound[] = {"voices\eng_enemyspotted", db-20, 1.0};
		titles[]={ };
	};	
	class Eng13
	{
		name = $STR_CFG_SOUNDS_ENG13;
		sound[] = {"voices\eng_everyoneout1", db-20, 1.0};
		titles[]={ };
	};
	class Eng14
	{
		name = $STR_CFG_SOUNDS_ENG14;
		sound[] = {"voices\eng_everyoneout2", db-20, 1.0};
		titles[]={ };
	};
	class Eng15
	{
		name = $STR_CFG_SOUNDS_ENG15;
		sound[] = {"voices\eng_forward", db-20, 1.0};
		titles[]={ };
	};
	class Eng16
	{
		name = $STR_CFG_SOUNDS_ENG16;
		sound[] = {"voices\eng_gettoutahere1", db-20, 1.0};
		titles[]={ };
	};
	class Eng17
	{
		name = $STR_CFG_SOUNDS_ENG17;
		sound[] = {"voices\eng_gettoutahere2", db-20, 1.0};
		titles[]={ };
	};
	class Eng18
	{
		name = $STR_CFG_SOUNDS_ENG18;
		sound[] = {"voices\eng_gettoyourpositions1", db-20, 1.0};
		titles[]={ };
	};
	class Eng19
	{
		name = $STR_CFG_SOUNDS_ENG19;
		sound[] = {"voices\eng_gettoyourpositions2", db-20, 1.0};
		titles[]={ };
	};
	class Eng20
	{
		name = $STR_CFG_SOUNDS_ENG20;
		sound[] = {"voices\eng_gogogo1", db-20, 1.0};
		titles[]={ };
	};
	class Eng21
	{
		name = $STR_CFG_SOUNDS_ENG21;
		sound[] = {"voices\eng_gogogo2", db-20, 1.0};
		titles[]={ };
	};
	class Eng22
	{
		name = $STR_CFG_SOUNDS_ENG22;
		sound[] = {"voices\eng_help1", db-20, 1.0};
		titles[]={ };
	};
	class Eng23
	{
		name = $STR_CFG_SOUNDS_ENG23;
		sound[] = {"voices\eng_help2", db-20, 1.0};
		titles[]={ };
	};
	class Eng24
	{
		name = $STR_CFG_SOUNDS_ENG24;
		sound[] = {"voices\eng_hey1", db-20, 1.0};
		titles[]={ };
	};
	class Eng25
	{
		name = $STR_CFG_SOUNDS_ENG25;
		sound[] = {"voices\eng_hey2", db-20, 1.0};
		titles[]={ };
	};
	class Eng26
	{
		name = $STR_CFG_SOUNDS_ENG26;
		sound[] = {"voices\eng_hey3", db-20, 1.0};
		titles[]={ };
	};	
	class Eng27
	{
		name = $STR_CFG_SOUNDS_ENG27;
		sound[] = {"voices\eng_letemhaveit1", db-20, 1.0};
		titles[]={ };
	};	
	class Eng28
	{
		name = $STR_CFG_SOUNDS_ENG28;
		sound[] = {"voices\eng_letemhaveit2", db-20, 1.0};
		titles[]={ };
	};	
	class Eng29
	{
		name = $STR_CFG_SOUNDS_ENG29;
		sound[] = {"voices\eng_lookout1", db-20, 1.0};
		titles[]={ };
	};		
	class Eng30
	{
		name = $STR_CFG_SOUNDS_ENG30;
		sound[] = {"voices\eng_lookout2", db-20, 1.0};
		titles[]={ };
	};		
	class Eng31
	{
		name = $STR_CFG_SOUNDS_ENG31;
		sound[] = {"voices\eng_lookout3", db-20, 1.0};
		titles[]={ };
	};		
	class Eng32
	{
		name = $STR_CFG_SOUNDS_ENG32;
		sound[] = {"voices\eng_medic1", db-20, 1.0};
		titles[]={ };
	};		
	class Eng33
	{
		name = $STR_CFG_SOUNDS_ENG33;
		sound[] = {"voices\eng_medic2", db-20, 1.0};
		titles[]={ };
	};		
	class Eng34
	{
		name = $STR_CFG_SOUNDS_ENG34;
		sound[] = {"voices\eng_medic3", db-20, 1.0};
		titles[]={ };
	};		
	class Eng35
	{
		name = $STR_CFG_SOUNDS_ENG35;
		sound[] = {"voices\eng_sectorclear1", db-20, 1.0};
		titles[]={ };
	};	
	class Eng36
	{
		name = $STR_CFG_SOUNDS_ENG36;
		sound[] = {"voices\eng_sectorclear2", db-20, 1.0};
		titles[]={ };
	};	
	class Eng37
	{
		name = $STR_CFG_SOUNDS_ENG37;
		sound[] = {"voices\eng_staysharp", db-20, 1.0};
		titles[]={ };
	};		
	class Eng38
	{
		name = $STR_CFG_SOUNDS_ENG38;
		sound[] = {"voices\eng_surrender", db-20, 1.0};
		titles[]={ };
	};	
	class Eng39
	{
		name = $STR_CFG_SOUNDS_ENG39;
		sound[] = {"voices\eng_underattack", db-20, 1.0};
		titles[]={ };
	};
	class Eng40
	{
		name = $STR_CFG_SOUNDS_ENG40;
		sound[] = {"voices\eng_whosthere1", db-20, 1.0};
		titles[]={ };
	};
	class Eng41
	{
		name = $STR_CFG_SOUNDS_ENG41;
		sound[] = {"voices\eng_whosthere2", db-20, 1.0};
		titles[]={ };
	};

	
	class Alarm
	{
		name = $STR_CFG_SOUNDS_ALARM;
		sound[] = {objects\air_raid, 1.0, 1.0};
		titles[] = {};
	};
	class Explosion1
	{
		name = $STR_CFG_SOUNDS_EXPLOSION1;
		sound[] = {Explosions\Explosion_Small2, 1.0, 1.0};
		titles[] = {};
	};
	class Explosion2
	{
		name = $STR_CFG_SOUNDS_EXPLOSION2;
		sound[] = {Explosions\Building_Demolition, 1.0, 1.0};
		titles[] = {};
	};
	
	class Fountain
	{
		name = $STR_CFG_SOUNDS_FOUNTAIN;
		sound[] = {Objects\stream, db-80, 1.0};
		titles[] = {};
	};
	class Fire
	{
		name = $STR_CFG_SOUNDS_FIRE;
		sound[] = {Objects\fire, db-72, 1.0};

		titles[] = {};
	};
};

class CfgTitles
{
	access = ReadAndCreate;
	titles[] = 
	{
		Sphere, BISLogo, TVSet // UbiLogo, 
		// Campaign, FirstBattle, NukeEden,
		// AttackKain, DefendEden, DefendAbel,
		// AttackEden
	};
	class Sphere
	{
		name = $STR_CFG_TITLES_SPHERE;
		model = "koule.p3d";
		duration = 5;
		camera[] = {0,0,-10};
	};
	
	class BISLogo
	{
		name = $STR_CFG_TITLES_BISLOGO;
		model = "bohemiaolor2.p3d";
		duration = 3;
		camera[] = {0,0,-200};
	};
	class TVSet
	{
		name=$STR_CFG_TITLES_TVSET;
		duration=1000; //how to do unlimited time?
		model = "TVhi.p3d"
		camera[] = {0,0,-0.7};
	};
};

class CfgIntro
{
	firstCampaign = "";
};

class CfgCredits
{
	cutscene = "xxcredits.eden";
};

#define TitleTxt 0 // faded text
#define TitleTxtDown 1 // down faded text
#define TitleRsc 2 // resource text
#define TitleObj 3 // object

class CfgCutScenes
{
	access = ReadAndCreate;
	class Refuel
	{
		sound[]={weapons\missload,0.5,0.2};
		titleType=TitleTxtDown;
		title=$STR_CFG_CUTSCENES_REFUEL;
	};
	class Rearm
	{
		sound[]={weapons\missload,0.3,1};
		titleType=TitleTxtDown;
		title=$STR_CFG_CUTSCENES_REARM;
	};
	class Repair
	{
		sound[]={weapons\missload,0.1,1};
		titleType=TitleTxtDown;
		title=$STR_CFG_CUTSCENES_REPAIR;
	};
	class Heal
	{
		sound[]={weapons\missload,0.1,1};
		titleType=TitleTxtDown;
		title=$STR_CFG_CUTSCENES_HEALING;
	};
	class TakeWeapon
	{
		sound[]={weapons\missload,0.1,1};
		titleType=TitleTxtDown;
		title=$STR_CFG_CUTSCENES_TAKEWEAPON;
	};
	class TakeMagazine
	{
		sound[]={weapons\missload,0.1,1};
		titleType=TitleTxtDown;
		title=$STR_CFG_CUTSCENES_TAKEMAGAZINE;
	};
	class DropWeapon
	{
		sound[]={weapons\missload,0.1,1};
		titleType=TitleTxtDown;
		title=$STR_CFG_CUTSCENES_DROPWEAPON;
	};
	class DropMagazine
	{
		sound[]={weapons\missload,0.1,1};
		titleType=TitleTxtDown;
		title=$STR_CFG_CUTSCENES_DROPMAGAZINE;
	};
};

#define CamExternal 0 // linked directly with object
#define CamInterpolated 0 // linked directly with object
#define CamStatic 1 // fixed point in space
#define CamStaticWithZoom 2 // fixed point in space
#define CamChained 3 // fixed point in space
#define CamTerminate 4 // fixed point in space
#define CamInternal 5 // fixed point in space

class CfgCameraEffects
{
	access = ReadAndCreate;
	class Interpolated
	{
		type=CamInterpolated;
		scale=0.1;
		duration=5;
		spline=true; // spline or linear
		show=public;
	};
	class Exact: Interpolated
	{
		scale=-1;
	};
	class Chain
	{
		type=CamChained;
		show=public;
	};

	class Array
	{
		class Terminate
		{
			name=$STR_CFG_CAMEFFECTS_TERMINATE;
			type=CamTerminate;
			show=private;
		};
		class Internal
		{
			name=$STR_CFG_CAMEFFECTS_INTERNAL;
			type=CamInternal;
			show=public;
		};

		/*
		class Camera1 : Exact
		{
			name="Face left";
			file="\dtaExt\camera1.p3d";
			duration=20;
			spline=true; // spline or linear
		};
		class Camera2 : Exact
		{
			name="Face right";
			file="\dtaExt\camera2.p3d";
			duration=20;
			spline=true; // spline or linear
		};
		class Camera3 : Exact
		{
			name="Scene zoom in";
			file="\dtaExt\camera3.p3d";
			duration=40;
			spline=true; // spline or linear
		};
		*/


		/*
		class SoldierDetail1 : Exact
		{
			name="Soldier Detail";
			file="\dtaExt\soldierMCanim1.p3d";
			scale=0.1;
			duration=60;
		};
		class SoldierDetail2 : Exact
		{
			name="Soldier Zoom In";
			file="\dtaExt\soldierMCanim2.p3d";
			scale=0.1;
			duration=20;
		};
		class SoldierDetail3 : Exact
		{
			name="Soldier Back";
			file="\dtaExt\soldierMCanim3.p3d";
			scale=0.1;
			duration=20;
		};
		*/


		class ZoomIn: Interpolated
		{
			name=$STR_CFG_CAMEFFECTS_ZOOMIN;
			file="\anim\cam_zoom_in_front";
			scale=0.1;
			duration=5;
		};
		class ZoomInSlow: Interpolated
		{
			name=$STR_CFG_CAMEFFECTS_ZOOMINSLOW;
			file="\anim\cam_zoom_in_front";
			scale=0.1;
			duration=15;
		};
		class Around: Interpolated
		{
			name=$STR_CFG_CAMEFFECTS_AROUND;
			file="\anim\cam_360";
			duration=10;
			scale=0.3;
		};
		class AroundSlow: Interpolated
		{
			name=$STR_CFG_CAMEFFECTS_AROUNDSLOW;
			file="\anim\cam_360";
			duration=20;
			scale=0.3;
		};
		class ZoomAndAround: Chain
		{
			name=$STR_CFG_CAMEFFECTS_ZOOMAROUND;
			chain[]={ZoomIn,Around};
		};
		class AroundAndZoomINSlow: Chain
		{
			name=$STR_CFG_CAMEFFECTS_AROUNDZOOMSLOW;
			chain[]={AroundSlow, ZoomInSlow};
		};
		class ZoomInS: Interpolated
		{
			name=$STR_CFG_CAMEFFECTS_ZOOMINS;
			file="cam_s_zoom_in";
			duration=5;
			scale=1;
			show = private;
		};
		class Fixed: Interpolated
		{
			name=$STR_CFG_CAMEFFECTS_FIXED;
			type=CamStatic;
			duration=10;
		};
		class FixedWithZoom: Fixed
		{
			name=$STR_CFG_CAMEFFECTS_FIXEDZOOM;
			type=CamStaticWithZoom;
			duration=10;
		};
		class External: Fixed
		{
			name=$STR_CFG_CAMEFFECTS_EXTERNAL;
			type=CamExternal;
			duration=5;
			file="";
		};

		/* 
		class Intro1 : Exact
		{
			name = "Intro 1";
			file="\anim\HANGAR_kancl_kam1";
			duration=60;
			show=private;
		};
		class Intro2 : Exact
		{

			name = "Intro 2";
			file="\anim\HANGAR_kancl_kam2";
			duration=80
			show=private;
		};
		class Intro3 : Exact
		{

			name = "Intro 3";
			file="\anim\HANGAR_kancl_kam3";
			duration=60;	
			show=private;
		};

		class IntroT: Chain
		{
			name="Intro (Terminated)";
			chain[]={Intro2, Intro3, Terminate};
		};

		class Presentation : Exact
		{
			name = "Presentation";
			file="\dtaExt\camin_b4.p3d";
			duration=150;
			show=private;
		};
		class PresentationT : Chain
		{
			name = "Presentation (Terminated)";
			chain[]={ Presentation, Terminate };
		};
		*/

	};
};

class CfgMarkers
{
	//access = ReadAndCreate;
	class Flag
	{
		name = $STR_CFG_MARKERS_FLAG;
		icon = "marker_objective.paa";
		color[] = {Red, 0.8};
		size = 32;
	};
	class Flag1
	{
		name = $STR_CFG_MARKERS_FLAG1;
		icon = "marker_waypoint.paa";
		color[] = {Red, 0.8};
		size = 32;
	};
	class Dot
	{
		name = $STR_CFG_MARKERS_DOT;
		icon = "marker_dot.paa";
		color[] = {Red, 0.8};
		size = 32;
	};
	class Destroy
	{
		name = $STR_CFG_MARKERS_DESTROY;
		icon = marker_destroy.paa;
		color[] = {Red, 0.8};
		size = 32;
	};
	class Start
	{
		name = $STR_CFG_MARKERS_START;
		icon = marker_start.paa;
		color[] = {Green, 0.8};
		size = 32;
	};
	class End
	{
		name = $STR_CFG_MARKERS_END;
		icon = marker_goal.paa;
		color[] = {Black, 0.8};
		size = 32;
	};
	class Warning
	{
		name = $STR_CFG_MARKERS_WARNING;
		icon = marker_exclamation.paa;
		color[] = {Black, 0.8};
		size = 32;
	};
	class Join
	{
		name = $STR_CFG_MARKERS_JOIN;
		icon = marker_join.paa;
		color[] = {Black, 0.8};
		size = 32;
	};
	class Pickup
	{
		name = $STR_CFG_MARKERS_PICKUP;
		icon = marker_pickup.paa;
		color[] = {Black, 0.8};
		size = 32;
	};
	class Unknown
	{
		name = $STR_CFG_MARKERS_UNKNOWN;
		icon = marker_question.paa;
		color[] = {Black, 0.8};
		size = 32;
	};
	class Marker
	{
		name = $STR_CFG_MARKERS_MARKER;
		icon = marker_x.paa;
		color[] = {Black, 0.8};
		size = 32;
	};
	class Arrow
	{
		name = $STR_CFG_MARKERS_ARROW;
		icon = "marker_sipka.paa";
		color[] = {Red, 0.8};
		size = 32;
	};
	class Empty
	{
		name = $STR_CFG_MARKERS_EMPTY;
		icon = marker_empty.paa;
		color[] = {0.0, 0.0, 0.2, 1.0};
		size = 0;
	};
};

class CfgMarkerColors
{
	//access = ReadAndCreate;
	class Default
	{
		name = $STR_CFG_MARKERCOL_DEFAULT;
		color[] = {Black, 0.8};
	};
	class ColorBlack
	{
		name = $STR_CFG_MARKERCOL_BLACK;
		color[] = {Black, 0.8};
	};
	class ColorRed
	{
		name = $STR_CFG_MARKERCOL_RED;
		color[] = {Red, 0.8};
	};
	class ColorRedAlpha
	{
		name = $STR_CFG_MARKERCOL_REDALPHA;
		color[] = {Red, 0.65};
	};
	class ColorGreen
	{
		name = $STR_CFG_MARKERCOL_GREEN;
		color[] = {Green, 0.8};
	};
	class ColorGreenAlpha
	{
		name = $STR_CFG_MARKERCOL_GREENALPHA;
		color[] = {Green, 0.65};
	};
	class ColorBlue
	{
		name = $STR_CFG_MARKERCOL_BLUE;
		color[] = {Blue, 0.8};
	};
	class ColorYellow
	{
		name = $STR_CFG_MARKERCOL_YELLOW;
		color[] = {Yellow, 0.8};
	};
	class ColorWhite
	{
		name = $STR_CFG_MARKERCOL_WHITE;
		color[] = {White, 1};
	};
};

class CfgMarkerBrushes
{
	//access = ReadAndCreate;
	class Solid
	{
		name = $STR_CFG_MARKERBR_SOLID;
		texture =;
	}
	class Horizontal
	{
		name = $STR_CFG_MARKERBR_HORIZONTAL;
		texture = 90_horizontal.paa;
	}
	class Vertical
	{
		name = $STR_CFG_MARKERBR_VERTICAL;
		texture = 90_vertical.paa;
	}
	class Grid
	{
		name = $STR_CFG_MARKERBR_GRID;
		texture = 90_mrizka.paa;
	}
	class FDiagonal
	{
		name = $STR_CFG_MARKERBR_FDIAGONAL;
		texture = 45_lp.paa;
	}
	class BDiagonal
	{
		name = $STR_CFG_MARKERBR_BDIAGONAL;
		texture = 45_pl.paa;
	}
	class DiagGrid
	{
		name = $STR_CFG_MARKERBR_DIAGGRID;
		texture = 45_mrizka.paa;
	}
	class Cross
	{
		name = $STR_CFG_MARKERBR_CROSS;
		texture = krizek.paa;
	}
};

// define initial word state
class CfgWorlds
{
	access = ReadAndCreate;
	eastSign=east_01.paa;
	westSign=west_01.paa;
	eastFlag=rus_vlajka.pac;
	westFlag=usa_vlajka.pac;
	guerrilaSign=guer_01.paa;
	guerrilaFlag=guer_01.paa;

	class GroupNameList
	{
		letters[] = 
		{
			Alpha, Bravo, Charlie, Delta, Echo, Foxtrot, Golf, Hotel, Kilo
		};
	};
	class GroupNames
	{
		// note: this is array of classes
		// it must not contain any non-class members
		class Alpha
		{
			name = $STR_CFG_GRPNAMES_ALPHA;
			image = "a.paa";
		};
		class Bravo
		{
			name = $STR_CFG_GRPNAMES_BRAVO;
			image = "b.paa";
		};
		class Charlie
		{
			name = $STR_CFG_GRPNAMES_CHARLIE;
			image = "c.paa";
		};
		class Delta
		{
			name = $STR_CFG_GRPNAMES_DELTA;
			image = "d.paa";
		};
		class Echo
		{
			name = $STR_CFG_GRPNAMES_ECHO;
			image = "e.paa";
		};
		class Foxtrot
		{
			name = $STR_CFG_GRPNAMES_FOXTROT;
			image = "f.paa";
		};
		class Golf
		{
			name = $STR_CFG_GRPNAMES_GOLF;
			image = "g.paa";
		};
		class Hotel
		{
			name = $STR_CFG_GRPNAMES_HOTEL;
			image = "h.paa";
		};
		class November
		{
			name = $STR_CFG_GRPNAMES_NOVEMBER;
			image = "a.paa";
		};
		class Kilo
		{
			name = $STR_CFG_GRPNAMES_KILO;
			image = "a.paa";
		};
		class Yankee
		{
			name = $STR_CFG_GRPNAMES_YANKEE;
			image = "a.paa";
		};
		class Zulu
		{
			name = $STR_CFG_GRPNAMES_ZULU;
			image = "a.paa";
		};
		class Two
		{
			name = $STR_CFG_GRPNAMES_TWO;
			image = "a.paa";
		};
		class Three
		{
			name = $STR_CFG_GRPNAMES_THREE;
			image = "a.paa";
		};
		class Buffalo
		{
			name = $STR_CFG_GRPNAMES_BUFFALO;
			image = "a.paa";
		};
		class Guardian
		{
			name = $STR_CFG_GRPNAMES_GUARDIAN;
			image = "a.paa";
		};
		class Convoy
		{
			name = $STR_CFG_GRPNAMES_CONVOY;
			image = "a.paa";
		};
		class Fox
		{
			name = $STR_CFG_GRPNAMES_FOX;
			image = "a.paa";
		};
	};
	class GroupColorList
	{
		colors[] = 
		{
			GroupColor1, GroupColor2, GroupColor3, GroupColor4, GroupColor5, GroupColor6, GroupColor7
		};
	};
	class GroupColors
	{
		//access = ReadOnlyVerified;
		// note: this is array of classes
		// it must not contain any non-class members
		class GroupColor1
		{
			name = $STR_CFG_GRPCOL_BLACK;
			image = "black.paa";
		};
		class GroupColor2
		{
			name = $STR_CFG_GRPCOL_RED;
			image = "red.paa";
		};
		class GroupColor3
		{
			name = $STR_CFG_GRPCOL_GREEN;
			image = "green.paa";
		};
		class GroupColor4
		{
			name = $STR_CFG_GRPCOL_BLUE;
			image = "blue.paa";
		};
		class GroupColor5
		{
			name = $STR_CFG_GRPCOL_YELLOW;
			image = "yellow.paa";
		};
		class GroupColor6
		{
			name = $STR_CFG_GRPCOL_ORANGE;
			image = "orange.paa";
		};
		class GroupColor7
		{
			name = $STR_CFG_GRPCOL_PINK;
			image = "pink.paa";
		};
		class GroupColor0
		{
			name = "";
			image = "";
		};
		class Six
		{
			name = $STR_CFG_GRPNAMES_SIX;
			image = "a.paa";
		};
	};

	class East	// East army definition
	{
		access = ReadAndWrite;
		#include "russiannames.hpp"
	};
	class West	// East army definition
	{
		#include "englishnames.hpp"
	};
	class Guerrila
	{
		#include "civiliannames.hpp"
	};
	class Civilian
	{
		#include "czechnames.hpp"
	};

	class DefaultWorld
	{
		access = ReadOnlyVerified;

		plateFormat="$$$  ## - ##";
		plateLetters="ABCDEFHIKLMOPRSTVXYZ"

		//default center position
		centerPosition[] = {6400, 6400, 0};

		latitude = -40; // positive is south
		longitude = +15; // positive is east

		class Music: CfgMusic {};
		class EnvSounds: CfgEnvSounds {};

		cutscenes[] = {intro}; 

		// forests
		forestOldTriangle = "data3D\les trojuhelnik.p3d";
		forestOldSquare = "data3D\les ctverec.p3d";
		forestInner = "data3D\les ctverec dark.p3d";
		forestOuter = "data3D\les ctverec pruchozi.p3d";
		forestOuterT1 = "data3D\les ctverec pruchozi_T1.p3d";
		forestOuterT2 = "data3D\les ctverec pruchozi_T2.p3d";
		forestTriangle = "data3D\les trojuhelnik pruchozi.p3d";
		forestBorder = "data3D\les ctverec mlazi.p3d";

		class ReplaceObjects
		{
			class ForestBorder
			{
				replace = "data3D\les ctverec mlazi.p3d";
				with[] = {};
			};
			class ForestTriangle
			{
				replace = "data3D\les trojuhelnik.p3d";
				with[] = {"data3D\les trojuhelnik pruchozi.p3d"};
			};
			class ForestSquare
			{
				replace = "data3D\les ctverec.p3d";
				with[] = 
				{
					"data3D\les ctverec pruchozi_T1.p3d",
					"data3D\les ctverec pruchozi_T2.p3d"
				};
				center = true;
			};
    };
    
		landGrid = 50; // grid size
		// landRange is stored directly in WRP file

		class Grid
		{
			offsetX = 0;
			offsetY = 0;
      class Zoom1
      {
				zoomMax = 0.2;
				format = "XY";
				formatX = "Aa";
				formatY = "00";
				stepX = 128;
				stepY = 128;
      };
      class Zoom2
      {
        zoomMax = 1e30;
        format = "XY";
        formatX = "A";
        formatY = "0";
        stepX = 1280;
        stepY = 1280;
      };
		};

		// fractal and white noise random offset are added
		// white noise generated more "wild" terrain
		// fractal tends to generate smooth, varied terrain
		class Subdivision
		{
			// fractal component of subdivision
			// changes are smaller for smaller rectangles
			class Fractal
			{
				// texture roughness factor
				rougness = 10;
				// max. value for squares containing road
				maxRoad = 0.2;
				// max. value for squares containing track
				maxTrack = 1.0;
				// max. coeficient depending on slope
				maxSlopeFactor = 0.05;
			};
			// white noise component of subdivision
			// change size is independent on rectangle size 
			class WhiteNoise
			{
				rougness = 5;
				// max. value for squares containing road
				maxRoad = 0.1;
				// max. value for squares containing track
				maxTrack = 0.5;
				// max. coeficient depending on slope
				maxSlopeFactor = 0.025;
			};

			// do not divide surfaces that are under given limit
			minY = -0.0;
			// do not divide flat surfaces
			minSlope = 0.02;
		};
	};
	class Eden: DefaultWorld
	{
		access = ReadOnlyVerified;

		plateFormat="ER$  ## - ##";
		plateLetters="ABCDEFHIKLMOPRSTVXYZ"

		worldName=eden.wrp;
		description = "Everon";
		icon=_eden.paa;
		startTime = 8:30;
		startDate = 30/4/84;
		startWeather = 0.3;
		startFog = 0.0;
		forecastWeather = 0.3;
		forecastFog = 0.0;
		seagullPos[] = {10738,8509};
		// landing place - airport
		ilsPosition[] ={4772,10923};
		ilsDirection[] ={0,0.08,-1};
		ilsTaxiIn[]=
		{
			4772+69,10923+400, // service path middle point
			4772+69,10923+95, // point on runway to start there
		
			4772+61,10923+87, // point on runway to start there

			4772+8,10923+87, // point on runway to start there
			4772,10923+95, // point on runway to start there
			4772,10923+150 // align with runway
		};
		ilsTaxiOff[]=
		{
			4772,10923, //ilsPos, // touchdown point on runway

			4772,10923+878, // move to taxi-off point
			4772+8,10923+886, // start turning

			4772+61,10923+886, // move to taxi-path
			4772+69,10923+878, // turn to service path

			4772+69,10923+400, // move on service path to middle point
		};
		// sound sources
		class Sounds
		{
			sounds[]={
				/*
				BadDog1,LittleDog1,BadDog2,LittleDog2,
				SorrowDog1, Owl1, Owl2, Cow1, Cow2, 
				Cikade1, Cikade2 */
			};
/*
			class BadDog1
			{
				simulation=BadDogSfx;
				position[] = edenobjDog1;
			};
			class LittleDog1
			{
				simulation=LittleDogSfx;
				position[] = edenobjDog2;
			};
			class SorrowDog1
			{
				simulation=SorrowDogSfx;
				position[] = edenobjDog3;
			};
			class BadDog2
			{
				simulation=DogSfx;
				position[] = edenobjDog4;
			};
			class LittleDog2
			{
				simulation=LittleDogSfx;
				position[] = edenobjDog5;
			};
			class Owl1
			{
				simulation=OwlSfx;
				position[] = eden_nightOwl;
			};
			class Owl2
			{
				simulation=OwlSfx;
				position[] = eden_nightOwl1;
			};
			class Cow1
			{
				simulation=CowSfx;
				position[] = edenobjKravin;
			};
			class Cow2
			{
				simulation=CowSfx;
				position[] = edenobjCow1;
			};
			class Cikade1
			{
				simulation=CricketSfx;
				position[] = edenobjCikade;
			};
			class Cikade2
			{
				simulation=CricketSfx;
				position[] = edenobjCvrcci;
			};
			*/
		};
		class Animation {vehicles[]={};}; // default - no film
		class Names
		{
			class SaintPhillippe
			{
				name = "Saint Phillippe";
				position[] = eden_vil_SaintPhillippe;
			};
			class Regina
			{
				name = "Regina";
				position[] = eden_vil_Regina;
			};
			class Meaux
			{
				name = "Meaux";
				position[] = eden_vil_Meaux;
			};
			class Tyrone
			{
				name = "Tyrone";
				position[] = eden_vil_Tyrone;
			};
			class Montignac
			{
				name = "Montignac";
				position[] = eden_vil_Montignac;
			};
			class Gravette
			{
				name = "Gravette";
				position[] = eden_vil_Gravette;
			};
			class EnreDeux
			{
				name = "Entre Deux";
				position[] = eden_vil_EnreDeux;
			};
			class Provins
			{
				name = "Provins";
				position[] = eden_vil_Provins;
			};
			class Chotain
			{
				name = "Chotain";
				position[] = eden_vil_Chotain;
			};
			class Laruns
			{
				name = "Laruns";
				position[] = eden_vil_Laruns;
			};
			class Figari
			{
				name = "Figari";
				position[] = eden_vil_Figari;
			};
			class LeMoule
			{
				name = "Le Moule";
				position[] = eden_vil_LeMoule;
			};
			class Morton
			{
				name = "Morton";
				position[] = eden_vil_Morton;
			};
			class Lamentin
			{
				name = "Lamentin";
				position[] = eden_vil_Lamentin;
			};
			class Levie
			{
				name = "Levie";
				position[] = eden_vil_Levie;
			};
			class Durras
			{
				name = "Durras";
				position[] = eden_vil_Durras;
			};
			class Vernon
			{
				name = "Vernon";
				position[] = eden_vil_Vernon;
			};
			class SaintPierre
			{
				name = "Saint Pierre";
				position[] = eden_vil_SaintPierre;
			};
		};
		cutscenes[] = {intro, intro1}; 
	};

	class Abel: DefaultWorld
	{
		access = ReadOnlyVerified;

		plateFormat="ML$ - #####";
		plateLetters="ABCDEGHIKLMNOPRSTVXZ"

		worldName=abel.wrp;
		description = "Malden";
		icon=_abel.paa;
		startTime = 8:30;
		startDate = 30/4/84;
		startWeather = 0.3;
		startFog = 0.0;
		forecastWeather = 0.3;
		forecastFog = 0.0;
		seagullPos[] = abelWestInvasion;
		// landing place - airport
		ilsPosition[] ={7922,9590,0};
		ilsDirection[] ={0,0.08,-1};

		ilsTaxiIn[]=
		{
			7922+69,9590+400, // service path middle point
			7922+69,9590+45-18, // point on runway to start there
		
			7922+61,9590+37-18, // point on runway to start there

			7922+8,9590+37-18, // point on runway to start there
			7922,9590+45-18, // point on runway to start there
			7922,9590+100-18 // align with runway
		};
		ilsTaxiOff[]=
		{
			7922,9590, //ilsPos, // touchdown point on runway

			7922,9590+878-18, // move to taxi-off point
			7922+8,9590+886-18, // start turning

			7922+61,9590+886-18, // move to taxi-path
			7922+69,9590+878-18, // turn to service path

			7922+69,9590+400, // move on service path to middle point
		};

		// forests
		forestOldTriangle = "data3D\les_su_trojuhelnik.p3d";
		forestOldSquare = "data3D\les_su_ctver.p3d";
		forestInner = "data3D\les_su_ctver.p3d";
		forestOuter = "data3D\les_su_ctver_pruhozi.p3d";
		forestOuterT1 = "data3D\les_su_ctver_pruhozi_T1.p3d";
		forestOuterT2 = "data3D\les_su_ctver_pruhozi_T2.p3d";
		forestTriangle = "data3D\les_su_trojuhelnik.p3d";
		forestBorder = "data3D\les_su_ctver_mlaz.p3d";

		class ReplaceObjects
		{
			class ForestBorder
			{
				replace = "data3D\les_su_ctver_mlaz.p3d";
				with[] = {};
			};
			class ForestSquare
			{
				replace = "data3D\les_su_ctver.p3d";
				with[] = 
				{
					"data3D\les_su_ctver_pruhozi_T1.p3d",
					"data3D\les_su_ctver_pruhozi_T2.p3d"
				};
				center = true;
			};
    };
		
		// sound sources
		class EnvSounds: CfgEnvSounds
		{
			class Rain // rain
			{
				sound[]={Environmental\Rain_hard,db-60,1};
				soundNight[]={Environmental\Rain_hard,db-60,1};
			};
			class Sea // sea
			{
				sound[]={Environmental\wave_break,db-80,1};
				soundNight[]={Environmental\wave_break,db-80,1};
			};
			class Meadows // default - no trees, no sea, no hills ...
			{
				sound[]={animals\crickets03,db-95,1};
				soundNight[]={animals\crickets03,db-95,1};
			};
			class Trees // trees
			{
				sound[]={animals\crickets03,db-80,1};
				soundNight[]={animals\crickets03,db-80,1};
			};
			class Hills // hills > 250m
			{
				sound[]={Environmental\wind_heavy,db-90,1};
				soundNight[]={Environmental\wind_whistle,db-90,1};
			};
		};
		class Sounds
		{
			sounds[]={};
		};
		class Animation {vehicles[]={};}; // default - no film
		class Names
		{
			class SaintLouis
			{
				name = "Saint Louis";
				position[] = Abel_vil_SaintLouis;
			};
			class Larche
			{
				name = "Larche";
				position[] = Abel_vil_Larche;
			};
			class LaTrinite
			{
				name = "La Trinite";
				position[] = Abel_vil_LaTrinite;
			};
			class Goisee
			{
				name = "Goisse";
				position[] =  Abel_vil_Goisse;
			};
			class LaPessagne
			{
				name = "La Pessagne";
				position[] = Abel_vil_LaPessagne;
			};
			class Vigny
			{
				name = "Vigny";
				position[] = Abel_vil_Vigny;
			};
			class Houdan
			{
				name = "Houdan";
				position[] = Abel_vil_Houdan;
			};
			class SainteMarie
			{
				name = "Sainte Marie";
				position[] = Abel_vil_SainteMarie;
			};
			class Chapoi
			{
				name = "Chapoi";
				position[] = Abel_vil_Chapoi;
			};
			class LePort
			{
				name = "Le Port";
				position[] = Abel_vil_LePort;
			};
			class Cancon
			{
				name = "Cancon";
				position[] = Abel_vil_Cancon;
			};
			class LaRiviere
			{
				name = "La Riviere";
				position[] = Abel_vil_LaRiviere;
			};
			class Arudy
			{
				name = "Arudy";
				position[] = Abel_vil_Arudy;
			};
			class Dourdan
			{
				name = "Dourdan";
				position[] = Abel_vil_Dourdan;
			};
			/*class Lolisse
			{
				name = "Lolisse";
				position[] = Abel_vil_Lolisse;
			};*/
		};
		cutscenes[] = {intro, intro1}; 
	};
	
	class Demo: Abel
	{
		access = ReadOnlyVerified;
		worldName=\demo\demo.wrp;
		description = "Malden - Demo";
	//	cutscenes[] = {intro, intro2, intro3}; 
		cutscenes[] = {intro}; 
	};
	
	class Cain: DefaultWorld
	{
		access = ReadOnlyVerified;
		plateFormat="## - KO$ - #";
		plateLetters="ABCEHKMOPT";

		worldName=cain.wrp;
		description = "Kolgujev";
		icon=_cain.paa;
		startTime = 8:30;
		startDate = 30/4/84;
		startWeather = 0.3;
		startFog = 0.0;
		forecastWeather = 0.3;
		forecastFog = 0.0;
		seagullPos[] = abelWestInvasion;
		// landing place - airport
		ilsPosition[] ={0,0,0}; // no airport?
		ilsDirection[] ={0,0.08,-1};
		ilsTaxiIn[]={};
		ilsTaxiOff[]={};
		// sound sources
		class Sounds
		{
			sounds[]={};
		};
		class Animation {vehicles[]={};}; // default - no film
		class Names
		{
		};
		cutscenes[] = {intro, intro1}; 
/*
		class Grid
		{
			offsetX = 0;
			offsetY = 256 * 50;
      class Zoom1
      {
				zoomMax = 0.2;
				format = "X.Y";
				formatX = "000";
				formatY = "000";
				stepX = 100;
				stepY = -100;
      };
      class Zoom2
      {
        zoomMax = 1e30;
        format = "X.Y";
        formatX = "00";
        formatY = "00";
        stepX = 1000;
        stepY = -1000;
      };
		};
*/
	};
	class Intro: DefaultWorld
	{
		access = ReadOnlyVerified;
		description = "Desert Island";
		icon=_training.paa;

		worldName=intro.wrp;

		plateFormat="ML$ - #####";
		plateLetters="ABCDEGHIKLMNOPRSTVXZ"

		//longitude = +140; // positive is east
		//latitude = +40; // positive is south

		startTime = 4:30;
		startDate = 10/4/82;
		startWeather = 0.4;
		startFog = 0.0;
		forecastWeather = 0.4;
		forecastFog = 0.0;
		seagullPos[] = minimalSeagullPos1;
		// landing place - airport
		ilsPosition[] ={0,0,0};
		ilsDirection[] ={0,0.08,1};
		ilsTaxiIn[]={};
		ilsTaxiOff[]={};

		//default center position
		centerPosition[] = {9735, 3964, 0};

		// sound sources
		class Sounds
		{
			sounds[]={};
		};
		class Animation {vehicles[]={};}; // default - no film
		class Names
		{
		};
		cutscenes[] = {intro}; 
	};


	initWorld = Intro;
	demoWorld = Demo;
	
/*	
	worlds[] =
	{
		Eden,
		Abel,
		Cain,
		Demo,
		//Minimal,
		Intro
	};
*/
};

class CfgWorldList
{
	// allow register new worlds here
	access = ReadAndCreate;
	class Eden {};
	class Abel {};
	class Cain {};
	class Demo {};
	class Intro {};
};

class CfgGroups
{
	//access = ReadAndCreate;
	// groups templates used in Insert group dialog

/*!
\patch 1.52 Date 4/19/2002 by Viktor
- Fixed: Bad position of last soldier when inserting group
*/

	class West
	{
		name = $STR_WEST;
		class Armored
		{
			name = $STR_CFG_GRP_ARMORED;

			class M1Platoon
			{
				name = $STR_CFG_GRP_M1PLATOON;
				class Unit0
				{
					side = TWest;
					vehicle = "M1Abrams";
					rank = "CAPTAIN";
					position[] = {0, +5, 0};
				}
				class Unit1
				{
					side = TWest;
					vehicle = "M1Abrams";
					rank = "Lieutnant";
					position[] = {-20, 0, 0};
				}
				class Unit2
				{
					side = TWest;
					vehicle = "M1Abrams";
					rank = "Lieutnant";
					position[] = {20, 0, 0};
				}
				class Unit3
				{
					side = TWest;
					vehicle = "M1Abrams";
					rank = "Corporal";
					position[] = {40, 0, 0};
				}
			};

			class M60Platoon
			{
				name = $STR_CFG_GRP_M60PLATOON;
				class Unit0
				{
					side = TWest;
					vehicle = "M60";
					rank = "CAPTAIN";
					position[] = {0, +5, 0};
				}
				class Unit1
				{
					side = TWest;
					vehicle = "M60";
					rank = "Lieutnant";
					position[] = {-20, 0, 0};
				}
				class Unit2
				{
					side = TWest;
					vehicle = "M60";
					rank = "Lieutnant";
					position[] = {20, 0, 0};
				}
				class Unit3
				{
					side = TWest;
					vehicle = "M60";
					rank = "Corporal";
					position[] = {40, 0, 0};
				}
			};
		};

		class Infantry
		{
			name = $STR_CFG_GRP_INFANTRY;

			class BasicInfantry
			{
				name = $STR_CFG_GRP_INFANTRY_BASIC;

				class Unit0
				{
					side = TWest;
					vehicle = "OfficerW";
					rank = "Sergeant";
					position[] = {0, +5, 0};
				};
				class Unit1
				{
					side = TWest;
					vehicle = "SoldierWMG";
					rank = "CORPORAL";
					position[] = {3, 0, 0};
				};
				class Unit2
				{
					side = TWest;
					vehicle = "SoldierWG";
					rank = "CORPORAL";
					position[] = {5,0,0};
				};
				class Unit3
				{
					side = TWest;
					vehicle = "SoldierWG";
					rank = "CORPORAL";
					position[] = {7,0,0};
				};
				class Unit4
				{
					side = TWest;
					vehicle = "SoldierWLAW";
					rank = "CORPORAL";
					position[] = {9,0,0};
				};
				class Unit5
				{
					side = TWest;
					vehicle = "SoldierWMG";
					rank = "Private";
					position[] = {11,0,0};
				};
				class Unit6
				{
					side = TWest;
					vehicle = "SoldierWB";
					rank = "Private";
					position[] = {13,0,0};
				};
				class Unit7
				{
					side = TWest;
					vehicle = "SoldierWB";
					rank = "Private";
					position[] = {15,0, 0};
				};
				class Unit8
				{
					side = TWest;
					vehicle = "SoldierWB";
					rank = "Private";
					position[] = {17,0, 0};
				};
			};

			class MechanizedInfantry
			{
				name = $STR_CFG_GRP_INFANTRY_MECHANIZED;

				class Unit0
				{
					side = TWest;
					vehicle = "OfficerW";
					rank = "Sergeant";
					position[] = {0, +5, 0};
				};
				class Unit1
				{
					side = TWest;
					vehicle = "M113";
					rank = "CORPORAL";
					position[] = {-5, 0, 0};
				};
				class Unit2
				{
					side = TWest;
					vehicle = "SoldierWG";
					rank = "CORPORAL";
					position[] = {5,0,0};
				};
				class Unit3
				{
					side = TWest;
					vehicle = "SoldierWG";
					rank = "CORPORAL";
					position[] = {7,0,0};
				};
				class Unit4
				{
					side = TWest;
					vehicle = "SoldierWLAW";
					rank = "CORPORAL";
					position[] = {9,0,0};
				};
				class Unit5
				{
					side = TWest;
					vehicle = "SoldierWMG";
					rank = "Private";
					position[] = {11,0,0};
				};
				class Unit6
				{
					side = TWest;
					vehicle = "SoldierWB";
					rank = "Private";
					position[] = {13,0,0};
				};
				class Unit7
				{
					side = TWest;
					vehicle = "SoldierWB";
					rank = "Private";
					position[] = {15,0, 0};
				};
			};
		};
	};

	class East
	{
		name = $STR_EAST;
		class Armored
		{
			name = $STR_CFG_GRP_ARMORED;

			class T80Platoon
			{
				name = $STR_CFG_GRP_T80PLATOON;
				class Unit0
				{
					side = TEast;
					vehicle = "T80";
					rank = "CAPTAIN";
					position[] = {0, +5, 0};
				}
				class Unit1
				{
					side = TEast;
					vehicle = "T80";
					rank = "Lieutnant";
					position[] = {-20, 0, 0};
				}
				class Unit2
				{
					side = TEast;
					vehicle = "T80";
					rank = "Lieutnant";
					position[] = {20, 0, 0};
				}
				class Unit3
				{
					side = TEast;
					vehicle = "T80";
					rank = "Corporal";
					position[] = {40, 0, 0};
				}
			};

			class T72Platoon
			{
				name = $STR_CFG_GRP_T72PLATOON;
				class Unit0
				{
					side = TEast;
					vehicle = "T72";
					rank = "CAPTAIN";
					position[] = {0, +5, 0};
				}
				class Unit1
				{
					side = TEast;
					vehicle = "T72";
					rank = "Lieutnant";
					position[] = {-20, 0, 0};
				}
				class Unit2
				{
					side = TEast;
					vehicle = "T72";
					rank = "Lieutnant";
					position[] = {20, 0, 0};
				}
				class Unit3
				{
					side = TEast;
					vehicle = "T72";
					rank = "Corporal";
					position[] = {40, 0, 0};
				}
			};
		};

		class Infantry
		{
			name = $STR_CFG_GRP_INFANTRY;

			class BasicInfantry
			{
				name = $STR_CFG_GRP_INFANTRY_BASIC;

				class Unit0
				{
					side = TEast;
					vehicle = "OfficerE";
					rank = "Sergeant";
					position[] = {0, +5, 0};
				};
				class Unit1
				{
					side = TEast;
					vehicle = "SoldierEMG";
					rank = "CORPORAL";
					position[] = {3, 0, 0};
				};
				class Unit2
				{
					side = TEast;
					vehicle = "SoldierEG";
					rank = "CORPORAL";
					position[] = {5,0,0};
				};
				class Unit3
				{
					side = TEast;
					vehicle = "SoldierEB";
					rank = "CORPORAL";
					position[] = {7,0,0};
				};
				class Unit4
				{
					side = TEast;
					vehicle = "SoldierELAW";
					rank = "CORPORAL";
					position[] = {9,0,0};
				};
				class Unit5
				{
					side = TEast;
					vehicle = "SoldierEMG";
					rank = "Private";
					position[] = {11,0,0};
				};
				class Unit6
				{
					side = TEast;
					vehicle = "SoldierEB";
					rank = "Private";
					position[] = {13,0,0};
				};
				class Unit7
				{
					side = TEast;
					vehicle = "SoldierEB";
					rank = "Private";
					position[] = {15,0, 0};
				};
				class Unit8
				{
					side = TEast;
					vehicle = "SoldierEB";
					rank = "Private";
					position[] = {17,0, 0};
				};
			};

			class MechanizedInfantry
			{
				name = $STR_CFG_GRP_INFANTRY_MECHANIZED;

				class Unit0
				{
					side = TEast;
					vehicle = "OfficerE";
					rank = "Sergeant";
					position[] = {0, +5, 0};
				};
				class Unit1
				{
					side = TEast;
					vehicle = "BMP";
					rank = "CORPORAL";
					position[] = {-5, 0, 0};
				};
				class Unit2
				{
					side = TEast;
					vehicle = "SoldierEG";
					rank = "CORPORAL";
					position[] = {5,0,0};
				};
				class Unit3
				{
					side = TEast;
					vehicle = "SoldierEB";
					rank = "CORPORAL";
					position[] = {7,0,0};
				};
				class Unit4
				{
					side = TEast;
					vehicle = "SoldierELAW";
					rank = "CORPORAL";
					position[] = {9,0,0};
				};
				class Unit5
				{
					side = TEast;
					vehicle = "SoldierEMG";
					rank = "Private";
					position[] = {11,0,0};
				};
				class Unit6
				{
					side = TEast;
					vehicle = "SoldierEB";
					rank = "Private";
					position[] = {13,0,0};
				};
				class Unit7
				{
					side = TEast;
					vehicle = "SoldierEB";
					rank = "Private";
					position[] = {15,0, 0};
				};
			};
		};
	};

};

class CfgAddons
{
	// addon configuration
	access = ReadOnly;
	// Following official addons should be always loaded if present
	// this should help to minimize compatibility problems
	// with older missions that do not have correct addons[] list
	// (This applies especially to mission using official weapons).
	class PreloadBanks
	{
		class WeaponBIStudio
		{
			list[]=
			{
				"LaserGuided\","ABox\","6G30\","Kozl\","G36A\","MM-1\","Steyr\",
				"Bizon\","XMS\","M41a\"
			};
		};
		class MiscBIStudio
		{
			list[]=
			{
				"Flags\","VoiceRH\"
			};
		};
	};
	class PreloadAddons
	{
		// all addons in this list are always considered to be active
		class WeaponBIStudio
		{
			list[]=
			{
				LaserGuided,6G30,Kozlice,G36A,MM1,Steyr,Bizon,XMS,M41a
			};
		};
		class MiscBIStudio
		{
			list[]={Flags1,VoiceRH};
		};
		class ResistanceBIStudio
		{
			list[]={Noe};
		};
	};
};
